/****************************************************************************************************//**
 * @file     ADuCM342.h
 *
 * @brief    CMSIS Cortex-M3 Core Peripheral Access Layer Header File for
 *           default ADuCM342 Device Series
 *
 * @version  v1.0
 * @date     January 2023
 *
 *******************************************************************************************************/



/** @addtogroup Analog Devices Inc.
  * @{
  */

/** @addtogroup ADuCM342
  * @{
  */

#ifndef __ADUCM342_H__
#define __ADUCM342_H__

#ifndef __NO_MMR_STRUCTS__
// The new style CMSIS structure definitions for MMRs clash with
// the old style defs. If the old style are required for compilation
// then set __NO_MMR_STRUCTS__ to 0x1
#define __NO_MMR_STRUCTS__ 0x1
#endif

#ifdef __cplusplus
extern "C" {
#endif

/* -------------------------  Interrupt Number Definition  ------------------------ */

typedef enum {
/* -------------------  Cortex-M3 Processor Exceptions Numbers  ------------------- */
  Reset_IRQn                        = -15,  /*!<   1  Reset Vector, invoked on Power up and warm reset */
  NonMaskableInt_IRQn               = -14,  /*!<   2  Non maskable Interrupt, cannot be stopped or preempted */
  HardFault_IRQn                    = -13,  /*!<   3  Hard Fault, all classes of Fault */
  MemoryManagement_IRQn             = -12,  /*!<   4  Memory Management, MPU mismatch, including Access Violation and No Match */
  BusFault_IRQn                     = -11,  /*!<   5  Bus Fault, Pre-Fetch-, Memory Access Fault, other address/memory related Fault */
  UsageFault_IRQn                   = -10,  /*!<   6  Usage Fault, i.e. Undef Instruction, Illegal State Transition */
  SVCall_IRQn                       = -5,   /*!<  11  System Service Call via SVC instruction */
  DebugMonitor_IRQn                 = -4,   /*!<  12  Debug Monitor                    */
  PendSV_IRQn                       = -2,   /*!<  14  Pendable request for system service */
  SysTick_IRQn                      = -1,   /*!<  15  System Tick Timer                */
// --------------------------  ADUCM342 Specific Interrupt Numbers  ------------------------------
  WUT_IRQn                          = 0,    /*!<   0  WUT                              */
  EINT0_IRQn                        = 1,    /*!<   1  EINT0                            */
  EINT1_IRQn                        = 2,    /*!<   2  EINT1                            */
  WDT_IRQn                          = 3,    /*!<   3  WDT                              */
  GPT_IRQn                          = 4,    /*!<   4  GPT                              */
  ADC_IRQn                          = 5,    /*!<   5  ADC                              */
  FLASH_IRQn                        = 6,    /*!<   6  FLASH                            */
  SPI_IRQn                          = 7,    /*!<   7  SPI                              */
  LIN0_IRQn                         = 8,    /*!<   8  LIN0                             */
  LIN1_IRQn                         = 9,    /*!<   9  LIN1                             */
  LIN2_IRQn                         = 10,   /*!<  10  LIN2                             */
  HV_IRQn                           = 11,   /*!<  11  HV                               */
  CALOSCRQn                         = 12,   /*!<  12  CALOSC                           */
  SRAM_IRQn                         = 13,   /*!<  13  SRAM                             */
  UNUSED1_IRQn                      = 14,   /*!<  14  Unused                           */
  UNUSED2_IRQn                      = 15,   /*!<  15  Unused                           */
  UNUSED3_IRQn                      = 16    /*!<  16  Unused                           */
} IRQn_Type;


/** @addtogroup Configuration_of_CMSIS
  * @{
  */

/* ================================================================================ */
/* ================      Processor and Core Peripheral Section     ================ */
/* ================================================================================ */

/* ----------------Configuration of the cm3 Processor and Core Peripherals---------------- */

#define __CM3_REV              0x0200       /*!< Cortex-M3 Core Revision          */
#define __MPU_PRESENT             0         /*!< MPU present or not                    */
#define __NVIC_PRIO_BITS          3         /*!< Number of Bits used for Priority Levels */
#define __Vendor_SysTickConfig    0         /*!< Set to 1 if different SysTick Config is used */
/** @} */ /* End of group Configuration_of_CMSIS */

#include <core_cm3.h>                       /*!< Cortex-M3 processor and core peripherals */
#include "system_ADuCM342.h"             /*!< ADUCM342 System                      */


// System Safety Measure SM91 Gain Coefficient

#define          SM91GN                     	            (*(volatile unsigned short      *) 0x000207E2)
#define          SM91GN_A                    	            0x000207E2

// System Serial ID

#define          SYS_IDBASE                                 (*(volatile unsigned long      *) 0x000207F0)
#define          SYS_IDBASE_A                               0x000207F0
// System Serial ID 0
#define          SYSSER0                                    (*(volatile unsigned long      *) 0x000207F0)
#define          SYSSER0_A                                  0x000207F0
// System Serial ID 1
#define          SYSSER1                                    (*(volatile unsigned long      *) 0x000207F4)
#define          SYSSER1_A                                  0x000207F4

// General-Purpose Timer 0

#define          GPTBASE                                    (*(volatile unsigned long      *) 0x40000000)
#define          GPTBASE_A                                  0x40000000
// Current count value LSB
#define          T0VAL0                                     (*(volatile unsigned short int *) 0x40000000)
#define          T0VAL0_A                                   0x40000000
#if           ALLOW_DEPRECATED_NAMES
// "GPTVALS_LOW" has been deprecated. Use "T0VAL0" instead.
#define          GPTVALS_LOW                                (*(volatile unsigned short int *) 0x40000000)
#define          GPTVALS_LOW_A                              0x40000000
// "GPT0VALSL" has been deprecated. Use "T0VAL0" instead.
#define          GPT0VALSL                                  (*(volatile unsigned short int *) 0x40000000)
#define          GPT0VALSL_A                                0x40000000
#endif
// Current count value MSB
#define          T0VAL1                                     (*(volatile unsigned short int *) 0x40000004)
#define          T0VAL1_A                                   0x40000004
#if           ALLOW_DEPRECATED_NAMES
// "GPTVALS_HIGH" has been deprecated. Use "T0VAL1" instead.
#define          GPTVALS_HIGH                               (*(volatile unsigned short int *) 0x40000004)
#define          GPTVALS_HIGH_A                             0x40000004
// "GPT0VALSH" has been deprecated. Use "T0VAL1" instead.
#define          GPT0VALSH                                  (*(volatile unsigned short int *) 0x40000004)
#define          GPT0VALSH_A                                0x40000004
#endif
// Control
#define          T0CON                                      (*(volatile unsigned short int *) 0x40000008)
#define          T0CON_A                                    0x40000008
#if           ALLOW_DEPRECATED_NAMES
// "GPTCON" has been deprecated. Use "T0CON" instead.
#define          GPTCON                                     (*(volatile unsigned short int *) 0x40000008)
#define          GPTCON_A                                   0x40000008
// "GPT0CON" has been deprecated. Use "T0CON" instead.
#define          GPT0CON                                    (*(volatile unsigned short int *) 0x40000008)
#define          GPT0CON_A                                  0x40000008
#endif
// Timer Enable
#define          T0EN                                       (*(volatile unsigned short int *) 0x4000000C)
#define          T0EN_A                                     0x4000000C
#if           ALLOW_DEPRECATED_NAMES
// "GPTWUF" has been deprecated. Use "T0EN" instead.
#define          GPTWUF                                     (*(volatile unsigned short int *) 0x4000000C)
#define          GPTWUF_A                                   0x4000000C
// "GPTEN" has been deprecated. Use "T0EN" instead.
#define          GPTEN                                      (*(volatile unsigned short int *) 0x4000000C)
#define          GPTEN_A                                    0x4000000C
#endif
// Timeout Field A LSB
#define          T0TOFA0                                    (*(volatile unsigned short int *) 0x40000010)
#define          T0TOFA0_A                                  0x40000010
#if           ALLOW_DEPRECATED_NAMES
// "GPTWUF1_LOW" has been deprecated. Use "T0TOFA0" instead.
#define          GPTWUF1_LOW                                (*(volatile unsigned short int *) 0x40000010)
#define          GPTWUF1_LOW_A                              0x40000010
// "T0WUFA0" has been deprecated. Use "T0TOFA0" instead.
#define          T0WUFA0                                    (*(volatile unsigned short int *) 0x40000010)
#define          T0WUFA0_A                                  0x40000010
#endif
//  Timeout Field A  MSB
#define          T0TOFA1                                    (*(volatile unsigned short int *) 0x40000014)
#define          T0TOFA1_A                                  0x40000014
#if           ALLOW_DEPRECATED_NAMES
// "GPTWUF1_HIGH" has been deprecated. Use "T0TOFA1" instead.
#define          GPTWUF1_HIGH                               (*(volatile unsigned short int *) 0x40000014)
#define          GPTWUF1_HIGH_A                             0x40000014
// "T0WUFA1" has been deprecated. Use "T0TOFA1" instead.
#define          T0WUFA1                                    (*(volatile unsigned short int *) 0x40000014)
#define          T0WUFA1_A                                  0x40000014
#endif
// Timeout Field B LSB
#define          T0TOFB0                                    (*(volatile unsigned short int *) 0x40000018)
#define          T0TOFB0_A                                  0x40000018
#if           ALLOW_DEPRECATED_NAMES
// "GPTWUF2_LOW" has been deprecated. Use "T0TOFB0" instead.
#define          GPTWUF2_LOW                                (*(volatile unsigned short int *) 0x40000018)
#define          GPTWUF2_LOW_A                              0x40000018
// "T0WUFB0" has been deprecated. Use "T0TOFB0" instead.
#define          T0WUFB0                                    (*(volatile unsigned short int *) 0x40000018)
#define          T0WUFB0_A                                  0x40000018
#endif
// Timeout Field B MSB
#define          T0TOFB1                                    (*(volatile unsigned short int *) 0x4000001C)
#define          T0TOFB1_A                                  0x4000001C
#if           ALLOW_DEPRECATED_NAMES
// "GPTWUF2_HIGH" has been deprecated. Use "T0TOFB1" instead.
#define          GPTWUF2_HIGH                               (*(volatile unsigned short int *) 0x4000001C)
#define          GPTWUF2_HIGH_A                             0x4000001C
// "T0WUFB1" has been deprecated. Use "T0TOFB1" instead.
#define          T0WUFB1                                    (*(volatile unsigned short int *) 0x4000001C)
#define          T0WUFB1_A                                  0x4000001C
#endif
// Timeout Field C LSB
#define          T0TOFC0                                    (*(volatile unsigned short int *) 0x40000020)
#define          T0TOFC0_A                                  0x40000020
#if           ALLOW_DEPRECATED_NAMES
// "GPTWUF3_LOW" has been deprecated. Use "T0TOFC0" instead.
#define          GPTWUF3_LOW                                (*(volatile unsigned short int *) 0x40000020)
#define          GPTWUF3_LOW_A                              0x40000020
// "T0WUFC0" has been deprecated. Use "T0TOFC0" instead.
#define          T0WUFC0                                    (*(volatile unsigned short int *) 0x40000020)
#define          T0WUFC0_A                                  0x40000020
#endif
// Timeout Field C MSB
#define          T0TOFC1                                    (*(volatile unsigned short int *) 0x40000024)
#define          T0TOFC1_A                                  0x40000024
#if           ALLOW_DEPRECATED_NAMES
// "GPTWUF3_HIGH" has been deprecated. Use "T0TOFC1" instead.
#define          GPTWUF3_HIGH                               (*(volatile unsigned short int *) 0x40000024)
#define          GPTWUF3_HIGH_A                             0x40000024
// "T0WUFC1" has been deprecated. Use "T0TOFC1" instead.
#define          T0WUFC1                                    (*(volatile unsigned short int *) 0x40000024)
#define          T0WUFC1_A                                  0x40000024
#endif
// Interrupt Enable
#define          T0IEN                                      (*(volatile unsigned short int *) 0x40000028)
#define          T0IEN_A                                    0x40000028
#if           ALLOW_DEPRECATED_NAMES
// "GPT0IEN" has been deprecated. Use "T0IEN" instead.
#define          GPT0IEN                                    (*(volatile unsigned short int *) 0x40000028)
#define          GPT0IEN_A                                  0x40000028
// "GPTIEN" has been deprecated. Use "T0IEN" instead.
#define          GPTIEN                                     (*(volatile unsigned short int *) 0x40000028)
#define          GPTIEN_A                                   0x40000028
#endif
// Interrupt Status
#define          T0ISTA                                     (*(volatile unsigned short int *) 0x4000002C)
#define          T0ISTA_A                                   0x4000002C
#if           ALLOW_DEPRECATED_NAMES
// "GPT0STA" has been deprecated. Use "T0ISTA" instead.
#define          GPT0STA                                    (*(volatile unsigned short int *) 0x4000002C)
#define          GPT0STA_A                                  0x4000002C
// "T0STA" has been deprecated. Use "T0ISTA" instead.
#define          T0STA                                      (*(volatile unsigned short int *) 0x4000002C)
#define          T0STA_A                                    0x4000002C
#endif
// Clear Interrupts
#define          T0CLRI                                     (*(volatile unsigned short int *) 0x40000030)
#define          T0CLRI_A                                   0x40000030
#if           ALLOW_DEPRECATED_NAMES
// "GPTCLRI" has been deprecated. Use "T0CLRI" instead.
#define          GPTCLRI                                    (*(volatile unsigned short int *) 0x40000030)
#define          GPTCLRI_A                                  0x40000030
// "GPT0CLRI" has been deprecated. Use "T0CLRI" instead.
#define          GPT0CLRI                                   (*(volatile unsigned short int *) 0x40000030)
#define          GPT0CLRI_A                                 0x40000030
#endif

// Clock Control

#define          CLKCTLBASE                                 (*(volatile unsigned long      *) 0x40002000)
#define          CLKCTLBASE_A                               0x40002000
// System Clock Control
#define          CLKCON                                     (*(volatile unsigned short int *) 0x40002000)
#define          CLKCON_A                                   0x40002000
#if           ALLOW_DEPRECATED_NAMES
// "CLKCTLBASE" has been deprecated. Use "CLKCON" instead.
#define          CLKCTLBASE                                 (*(volatile unsigned short int *) 0x40002000)
#define          CLKCTLBASE_A                               0x40002000
// "POWCON" has been deprecated. Use "CLKCON" instead.
#define          POWCON                                     (*(volatile unsigned short int *) 0x40002000)
#define          POWCON_A                                   0x40002000
#endif

// Hardware Identification register
#define          CHIPID                                     (*(volatile unsigned short int *) 0x40002024)
#define          CHIPID_A                                   0x40002024

// SRAM

#define          SRAMBASE                                   (*(volatile unsigned long      *) 0x4000202C)
#define          SRAMBASE_A                                 0x4000202C
// SRAM Control
#define          SRAMCTRL                                   (*(volatile unsigned short int *) 0x4000202C)
#define          SRAMCTRL_A                                 0x4000202C
#if           ALLOW_DEPRECATED_NAMES
// "SRAMCTL" has been deprecated. Use "SRAMCTRL" instead.
#define          SRAMCTL                                    (*(volatile unsigned short int *) 0x4000202C)
#define          SRAMCTL_A                                  0x4000202C
#endif
// SRAM Error Location
#define          SRAMERR                                    (*(volatile unsigned short int *) 0x40002030)
#define          SRAMERR_A                                  0x40002030

// Power Mode

#define          PWRBASE                                    (*(volatile unsigned long      *) 0x40002400)
#define          PWRBASE_A                                  0x40002400
// Power Mode
#define          PWRMOD                                     (*(volatile unsigned char      *) 0x40002400)
#define          PWRMOD_A                                   0x40002400
#if           ALLOW_DEPRECATED_NAMES
// "AONMOD" has been deprecated. Use "PWRMOD" instead.
#define          AONMOD                                     (*(volatile unsigned char      *) 0x40002400)
#define          AONMOD_A                                   0x40002400
#endif
// Power Modes Key Register
#define          PWRKEY                                     (*(volatile unsigned short int *) 0x40002404)
#define          PWRKEY_A                                   0x40002404
#if           ALLOW_DEPRECATED_NAMES
// "AONKEY" has been deprecated. Use "PWRKEY" instead.
#define          AONKEY                                     (*(volatile unsigned short int *) 0x40002404)
#define          AONKEY_A                                   0x40002404
#endif

// External Interrupts

#define          EXINTBASE                                  (*(volatile unsigned long      *) 0x40002420)
#define          EXINTBASE_A                                0x40002420
// External Interrupt Configuration
#define          EI0CFG                                     (*(volatile unsigned short int *) 0x40002420)
#define          EI0CFG_A                                   0x40002420
#if           ALLOW_DEPRECATED_NAMES
// "INTCTRL0" has been deprecated. Use "EI0CFG" instead.
#define          INTCTRL0                                   (*(volatile unsigned short int *) 0x40002420)
#define          INTCTRL0_A                                 0x40002420
#endif
// External Interrupt Clear
#define          EICLR                                      (*(volatile unsigned short int *) 0x40002430)
#define          EICLR_A                                    0x40002430
#if           ALLOW_DEPRECATED_NAMES
// "INTCLR1" has been deprecated. Use "EICLR" instead.
#define          INTCLR1                                    (*(volatile unsigned short int *) 0x40002430)
#define          INTCLR1_A                                  0x40002430
#endif

// Reset

#define          RSTBASE                                    (*(volatile unsigned long      *) 0x40002440)
#define          RSTBASE_A                                  0x40002440
// Reset Status
#define          RSTSTA                                     (*(volatile unsigned char      *) 0x40002440)
#define          RSTSTA_A                                   0x40002440
// Reset Clear
#define          RSTCLR                                     (*(volatile unsigned char      *) 0x40002440)
#define          RSTCLR_A                                   0x40002440

// Wake Up Timer

#define          WUTBASE                                    (*(volatile unsigned long      *) 0x40002500)
#define          WUTBASE_A                                  0x40002500
// Current count value LSB
#define          T2VAL0                                     (*(volatile unsigned short int *) 0x40002500)
#define          T2VAL0_A                                   0x40002500
#if           ALLOW_DEPRECATED_NAMES
// "WUTVALS_LOW" has been deprecated. Use "T2VAL0" instead.
#define          WUTVALS_LOW                                (*(volatile unsigned short int *) 0x40002500)
#define          WUTVALS_LOW_A                              0x40002500
// "WUT0VALSL" has been deprecated. Use "T2VAL0" instead.
#define          WUT0VALSL                                  (*(volatile unsigned short int *) 0x40002500)
#define          WUT0VALSL_A                                0x40002500
#endif
// Current count value MSB
#define          T2VAL1                                     (*(volatile unsigned short int *) 0x40002504)
#define          T2VAL1_A                                   0x40002504
#if           ALLOW_DEPRECATED_NAMES
// "WUTVALS_HIGH" has been deprecated. Use "T2VAL1" instead.
#define          WUTVALS_HIGH                               (*(volatile unsigned short int *) 0x40002504)
#define          WUTVALS_HIGH_A                             0x40002504
// "WUT0VALSH" has been deprecated. Use "T2VAL1" instead.
#define          WUT0VALSH                                  (*(volatile unsigned short int *) 0x40002504)
#define          WUT0VALSH_A                                0x40002504
#endif
// Control
#define          T2CON                                      (*(volatile unsigned short int *) 0x40002508)
#define          T2CON_A                                    0x40002508
#if           ALLOW_DEPRECATED_NAMES
// "WUTCON" has been deprecated. Use "T2CON" instead.
#define          WUTCON                                     (*(volatile unsigned short int *) 0x40002508)
#define          WUTCON_A                                   0x40002508
// "WUT0CON" has been deprecated. Use "T2CON" instead.
#define          WUT0CON                                    (*(volatile unsigned short int *) 0x40002508)
#define          WUT0CON_A                                  0x40002508
#endif
// Enable
#define          T2EN                                       (*(volatile unsigned short int *) 0x4000250C)
#define          T2EN_A                                     0x4000250C
#if           ALLOW_DEPRECATED_NAMES
// "WUTEN" has been deprecated. Use "T2EN" instead.
#define          WUTEN                                      (*(volatile unsigned short int *) 0x4000250C)
#define          WUTEN_A                                    0x4000250C
#endif
// Wake Up Field A LSB
#define          T2WUFA0                                    (*(volatile unsigned short int *) 0x40002510)
#define          T2WUFA0_A                                  0x40002510
#if           ALLOW_DEPRECATED_NAMES
// "T2WUTFA0" has been deprecated. Use "T2WUFA0" instead.
#define          T2WUTFA0                                   (*(volatile unsigned short int *) 0x40002510)
#define          T2WUTFA0_A                                 0x40002510
// "WUTWUF1_LOW" has been deprecated. Use "T2WUFA0" instead.
#define          WUTWUF1_LOW                                (*(volatile unsigned short int *) 0x40002510)
#define          WUTWUF1_LOW_A                              0x40002510
#endif
// Wake Up Field A MSB
#define          T2WUFA1                                    (*(volatile unsigned short int *) 0x40002514)
#define          T2WUFA1_A                                  0x40002514
#if           ALLOW_DEPRECATED_NAMES
// "T2WUTFA1" has been deprecated. Use "T2WUFA1" instead.
#define          T2WUTFA1                                   (*(volatile unsigned short int *) 0x40002514)
#define          T2WUTFA1_A                                 0x40002514
// "WUTWUF1_HIGH" has been deprecated. Use "T2WUFA1" instead.
#define          WUTWUF1_HIGH                               (*(volatile unsigned short int *) 0x40002514)
#define          WUTWUF1_HIGH_A                             0x40002514
#endif
// Wake Up Field B LSB
#define          T2WUFB0                                    (*(volatile unsigned short int *) 0x40002518)
#define          T2WUFB0_A                                  0x40002518
#if           ALLOW_DEPRECATED_NAMES
// "T2WUTFB0" has been deprecated. Use "T2WUFB0" instead.
#define          T2WUTFB0                                   (*(volatile unsigned short int *) 0x40002518)
#define          T2WUTFB0_A                                 0x40002518
// "WUTWUF2_LOW" has been deprecated. Use "T2WUFB0" instead.
#define          WUTWUF2_LOW                                (*(volatile unsigned short int *) 0x40002518)
#define          WUTWUF2_LOW_A                              0x40002518
#endif
// Wake Up Field B MSB
#define          T2WUFB1                                    (*(volatile unsigned short int *) 0x4000251C)
#define          T2WUFB1_A                                  0x4000251C
#if           ALLOW_DEPRECATED_NAMES
// "T2WUTFB1" has been deprecated. Use "T2WUFB1" instead.
#define          T2WUTFB1                                   (*(volatile unsigned short int *) 0x4000251C)
#define          T2WUTFB1_A                                 0x4000251C
// "WUTWUF2_HIGH" has been deprecated. Use "T2WUFB1" instead.
#define          WUTWUF2_HIGH                               (*(volatile unsigned short int *) 0x4000251C)
#define          WUTWUF2_HIGH_A                             0x4000251C
#endif
// Wake Up Field C LSB
#define          T2WUFC0                                    (*(volatile unsigned short int *) 0x40002520)
#define          T2WUFC0_A                                  0x40002520
#if           ALLOW_DEPRECATED_NAMES
// "T2WUTFC0" has been deprecated. Use "T2WUFC0" instead.
#define          T2WUTFC0                                   (*(volatile unsigned short int *) 0x40002520)
#define          T2WUTFC0_A                                 0x40002520
// "WUTWUF3_LOW" has been deprecated. Use "T2WUFC0" instead.
#define          WUTWUF3_LOW                                (*(volatile unsigned short int *) 0x40002520)
#define          WUTWUF3_LOW_A                              0x40002520
#endif
// Wake Up Field C MSB
#define          T2WUFC1                                    (*(volatile unsigned short int *) 0x40002524)
#define          T2WUFC1_A                                  0x40002524
#if           ALLOW_DEPRECATED_NAMES
// "T2WUTFC1" has been deprecated. Use "T2WUFC1" instead.
#define          T2WUTFC1                                   (*(volatile unsigned short int *) 0x40002524)
#define          T2WUTFC1_A                                 0x40002524
// "WUTWUF3_HIGH" has been deprecated. Use "T2WUFC1" instead.
#define          WUTWUF3_HIGH                               (*(volatile unsigned short int *) 0x40002524)
#define          WUTWUF3_HIGH_A                             0x40002524
#endif
// Interrupt Enable
#define          T2IEN                                      (*(volatile unsigned short int *) 0x40002528)
#define          T2IEN_A                                    0x40002528
#if           ALLOW_DEPRECATED_NAMES
// "WUTIEN" has been deprecated. Use "T2IEN" instead.
#define          WUTIEN                                     (*(volatile unsigned short int *) 0x40002528)
#define          WUTIEN_A                                   0x40002528
// "WUT0IEN" has been deprecated. Use "T2IEN" instead.
#define          WUT0IEN                                    (*(volatile unsigned short int *) 0x40002528)
#define          WUT0IEN_A                                  0x40002528
#endif
// Interrupt Status
#define          T2ISTA                                     (*(volatile unsigned short int *) 0x4000252C)
#define          T2ISTA_A                                   0x4000252C
#if           ALLOW_DEPRECATED_NAMES
// "WUT0STA" has been deprecated. Use "T2ISTA" instead.
#define          WUT0STA                                    (*(volatile unsigned short int *) 0x4000252C)
#define          WUT0STA_A                                  0x4000252C
// "WUTIST" has been deprecated. Use "T2ISTA" instead.
#define          WUTIST                                     (*(volatile unsigned short int *) 0x4000252C)
#define          WUTIST_A                                   0x4000252C
#endif
// Clear Interrupts
#define          T2CLRI                                     (*(volatile unsigned short int *) 0x40002530)
#define          T2CLRI_A                                   0x40002530
#if           ALLOW_DEPRECATED_NAMES
// "WUTCLRI" has been deprecated. Use "T2CLRI" instead.
#define          WUTCLRI                                    (*(volatile unsigned short int *) 0x40002530)
#define          WUTCLRI_A                                  0x40002530
// "WUT0CLRI" has been deprecated. Use "T2CLRI" instead.
#define          WUT0CLRI                                   (*(volatile unsigned short int *) 0x40002530)
#define          WUT0CLRI_A                                 0x40002530
#endif
// Capture Event Count LSB
#define          T2CAP0                                     (*(volatile unsigned short int *) 0x4000253C)
#define          T2CAP0_A                                   0x4000253C
#if           ALLOW_DEPRECATED_NAMES
// "WUT0CAP_LOW" has been deprecated. Use "T2CAP0" instead.
#define          WUT0CAP_LOW                                (*(volatile unsigned short int *) 0x4000253C)
#define          WUT0CAP_LOW_A                              0x4000253C
// "WUTCMP0_LOW" has been deprecated. Use "T2CAP0" instead.
#define          WUTCMP0_LOW                                (*(volatile unsigned short int *) 0x4000253C)
#define          WUTCMP0_LOW_A                              0x4000253C
#endif
// Capture Event Count MSB
#define          T2CAP1                                     (*(volatile unsigned short int *) 0x40002540)
#define          T2CAP1_A                                   0x40002540
#if           ALLOW_DEPRECATED_NAMES
// "WUT0CAP_HIGH" has been deprecated. Use "T2CAP1" instead.
#define          WUT0CAP_HIGH                               (*(volatile unsigned short int *) 0x40002540)
#define          WUT0CAP_HIGH_A                             0x40002540
// "WUTCMP0_HIGH" has been deprecated. Use "T2CAP1" instead.
#define          WUTCMP0_HIGH                               (*(volatile unsigned short int *) 0x40002540)
#define          WUTCMP0_HIGH_A                             0x40002540
#endif

// Watchdog Timer

#define          WDTBASE                                    (*(volatile unsigned long      *) 0x40002580)
#define          WDTBASE_A                                  0x40002580
// Load Value
#define          T3LD                                       (*(volatile unsigned short int *) 0x40002580)
#define          T3LD_A                                     0x40002580
#if           ALLOW_DEPRECATED_NAMES
// "WDGLD" has been deprecated. Use "T3LD" instead.
#define          WDGLD                                      (*(volatile unsigned short int *) 0x40002580)
#define          WDGLD_A                                    0x40002580
#endif
// Current count value
#define          T3VAL                                      (*(volatile unsigned short int *) 0x40002584)
#define          T3VAL_A                                    0x40002584
#if           ALLOW_DEPRECATED_NAMES
// "WDGVALS" has been deprecated. Use "T3VAL" instead.
#define          WDGVALS                                    (*(volatile unsigned short int *) 0x40002584)
#define          WDGVALS_A                                  0x40002584
#endif
// Control
#define          T3CON                                      (*(volatile unsigned short int *) 0x40002588)
#define          T3CON_A                                    0x40002588
#if           ALLOW_DEPRECATED_NAMES
// "WDGCON" has been deprecated. Use "T3CON" instead.
#define          WDGCON                                     (*(volatile unsigned short int *) 0x40002588)
#define          WDGCON_A                                   0x40002588
#endif
// Clear Interrupt
#define          T3CLRI                                     (*(volatile unsigned short int *) 0x4000258C)
#define          T3CLRI_A                                   0x4000258C
#if           ALLOW_DEPRECATED_NAMES
// "WDGCLRI" has been deprecated. Use "T3CLRI" instead.
#define          WDGCLRI                                    (*(volatile unsigned short int *) 0x4000258C)
#define          WDGCLRI_A                                  0x4000258C
#endif
// Status
#define          T3STA                                      (*(volatile unsigned short int *) 0x40002598)
#define          T3STA_A                                    0x40002598
#if           ALLOW_DEPRECATED_NAMES
// "WDGSTA" has been deprecated. Use "T3STA" instead.
#define          WDGSTA                                     (*(volatile unsigned short int *) 0x40002598)
#define          WDGSTA_A                                   0x40002598
#endif

// High Voltage Interface

#define          HVBASE                                     (*(volatile unsigned long      *) 0x40003000)
#define          HVBASE_A                                   0x40003000
// Write commands
#define          HVCON                                      (*(volatile unsigned char      *) 0x40003004)
#define          HVCON_A                                    0x40003004
// Write data
#define          HVDAT                                      (*(volatile unsigned char      *) 0x4000300C)
#define          HVDAT_A                                    0x4000300C
// Configuration shadow register
#define          HVDCFG0                                    (*(volatile unsigned char      *) 0x40003010)
#define          HVDCFG0_A                                  0x40003010
// Status shadow register
#define          HVDSTA                                     (*(volatile unsigned char      *) 0x40003018)
#define          HVDSTA_A                                   0x40003018

// SPI

#define          SPIBASE                                    (*(volatile unsigned long      *) 0x40004000)
#define          SPIBASE_A                                  0x40004000
// Status
#define          SPISTA                                     (*(volatile unsigned short int *) 0x40004000)
#define          SPISTA_A                                   0x40004000
#if           ALLOW_DEPRECATED_NAMES
// "SPI0STAT" has been deprecated. Use "SPISTA" instead.
#define          SPI0STAT                                   (*(volatile unsigned short int *) 0x40004000)
#define          SPI0STAT_A                                 0x40004000
#endif
// 8-bit receive
#define          SPIRX                                      (*(volatile unsigned short int *) 0x40004004)
#define          SPIRX_A                                    0x40004004
#if           ALLOW_DEPRECATED_NAMES
// "SPI0RX" has been deprecated. Use "SPIRX" instead.
#define          SPI0RX                                     (*(volatile unsigned short int *) 0x40004004)
#define          SPI0RX_A                                   0x40004004
#endif
// 8-bit transmit
#define          SPITX                                      (*(volatile unsigned short int *) 0x40004008)
#define          SPITX_A                                    0x40004008
#if           ALLOW_DEPRECATED_NAMES
// "SPI0TX" has been deprecated. Use "SPITX" instead.
#define          SPI0TX                                     (*(volatile unsigned short int *) 0x40004008)
#define          SPI0TX_A                                   0x40004008
#endif
// 8-bit baud rate selection
#define          SPIDIV                                     (*(volatile unsigned short int *) 0x4000400C)
#define          SPIDIV_A                                   0x4000400C
#if           ALLOW_DEPRECATED_NAMES
// "SPI0DIV" has been deprecated. Use "SPIDIV" instead.
#define          SPI0DIV                                    (*(volatile unsigned short int *) 0x4000400C)
#define          SPI0DIV_A                                  0x4000400C
#endif
// 16-bit configuration
#define          SPICON                                     (*(volatile unsigned short int *) 0x40004010)
#define          SPICON_A                                   0x40004010
#if           ALLOW_DEPRECATED_NAMES
// "SPI0CTRL" has been deprecated. Use "SPICON" instead.
#define          SPI0CTRL                                   (*(volatile unsigned short int *) 0x40004010)
#define          SPI0CTRL_A                                 0x40004010
#endif

// LIN

#define          LINBASE                                    (*(volatile unsigned long      *) 0x40005000)
#define          LINBASE_A                                  0x40005000
// LIN control
#define          LINCON                                     (*(volatile unsigned short int *) 0x40005000)
#define          LINCON_A                                   0x40005000
// LIN interrupt mask
#define          LINIMSK                                    (*(volatile unsigned short int *) 0x40005004)
#define          LINIMSK_A                                  0x40005004
#if           ALLOW_DEPRECATED_NAMES
// "LINMASK" has been deprecated. Use "LINIMSK" instead.
#define          LINMASK                                    (*(volatile unsigned short int *) 0x40005004)
#define          LINMASK_A                                  0x40005004
#endif
// Baud rate count
#define          LINBR                                      (*(volatile unsigned short int *) 0x40005008)
#define          LINBR_A                                    0x40005008
// Break symbol count
#define          LINBRK                                     (*(volatile unsigned short int *) 0x4000500C)
#define          LINBRK_A                                   0x4000500C
// LIN sampling delay count
#define          LINSAMP                                    (*(volatile unsigned short int *) 0x40005014)
#define          LINSAMP_A                                  0x40005014
// Forces LIN low while its value  > 0
#define          LINFORCE                                   (*(volatile unsigned short int *) 0x40005018)
#define          LINFORCE_A                                 0x40005018
// Time of the minimum low time that will wake up the device
#define          LINWUP                                     (*(volatile unsigned short int *) 0x4000501C)
#define          LINWUP_A                                   0x4000501C
#if           ALLOW_DEPRECATED_NAMES
// "LINWKUP" has been deprecated. Use "LINWUP" instead.
#define          LINWKUP                                    (*(volatile unsigned short int *) 0x4000501C)
#define          LINWKUP_A                                  0x4000501C
#endif
// Byte count  for the entire LIN frame
#define          LINCNT                                     (*(volatile unsigned char      *) 0x40005020)
#define          LINCNT_A                                   0x40005020
// Transceiver compensation delay time
#define          LINTRDLY                                   (*(volatile unsigned char      *) 0x40005024)
#define          LINTRDLY_A                                 0x40005024
#if           ALLOW_DEPRECATED_NAMES
// "TRDLY" has been deprecated. Use "LINTRDLY" instead.
#define          TRDLY                                      (*(volatile unsigned char      *) 0x40005024)
#define          TRDLY_A                                    0x40005024
#endif
// Bus idle timeout
#define          LINSLP                                     (*(volatile unsigned char      *) 0x40005028)
#define          LINSLP_A                                   0x40005028
// Number of bytes in the last response frame
#define          LINLCNT                                    (*(volatile unsigned char      *) 0x4000502C)
#define          LINLCNT_A                                  0x4000502C
// LIN Status
#define          LINSTA                                     (*(volatile unsigned short int *) 0x40005030)
#define          LINSTA_A                                   0x40005030
// LIN Status 1
#define          LINSTA1                                    (*(volatile unsigned short int *) 0x40005038)
#define          LINSTA1_A                                  0x40005038
// PID received
#define          LINID                                      (*(volatile unsigned char      *) 0x4000503C)
#define          LINID_A                                    0x4000503C
#if           ALLOW_DEPRECATED_NAMES
// "LINPID" has been deprecated. Use "LINID" instead.
#define          LINPID                                     (*(volatile unsigned char      *) 0x4000503C)
#define          LINPID_A                                   0x4000503C
#endif
// LIN data byte 1 for Rx or Tx
#define          LIND1                                      (*(volatile unsigned char      *) 0x40005040)
#define          LIND1_A                                    0x40005040
// LIN data byte 2 for Rx or Tx
#define          LIND2                                      (*(volatile unsigned char      *) 0x40005044)
#define          LIND2_A                                    0x40005044
// LIN data byte 3 for Rx or Tx
#define          LIND3                                      (*(volatile unsigned char      *) 0x40005048)
#define          LIND3_A                                    0x40005048
// LIN data byte 4 for Rx or Tx
#define          LIND4                                      (*(volatile unsigned char      *) 0x4000504C)
#define          LIND4_A                                    0x4000504C
// LIN data byte 5 for Rx or Tx
#define          LIND5                                      (*(volatile unsigned char      *) 0x40005050)
#define          LIND5_A                                    0x40005050
// LIN data byte 6 for Rx or Tx
#define          LIND6                                      (*(volatile unsigned char      *) 0x40005054)
#define          LIND6_A                                    0x40005054
// LIN data byte 7 for Rx or Tx
#define          LIND7                                      (*(volatile unsigned char      *) 0x40005058)
#define          LIND7_A                                    0x40005058
// LIN data byte 8 for Rx or Tx
#define          LIND8                                      (*(volatile unsigned char      *) 0x4000505C)
#define          LIND8_A                                    0x4000505C
// LIN frame checksum
#define          LINFCS                                     (*(volatile unsigned char      *) 0x40005060)
#define          LINFCS_A                                   0x40005060
// Current calculated checksum
#define          LINCCS                                     (*(volatile unsigned char      *) 0x40005064)
#define          LINCCS_A                                   0x40005064
// Node ID Address
#define          LINNAD                                     (*(volatile unsigned char      *) 0x40005068)
#define          LINNAD_A                                   0x40005068
// Initial node ID
#define          LININAD                                    (*(volatile unsigned char      *) 0x4000506C)
#define          LININAD_A                                  0x4000506C
// Initial function ID
#define          LINFID                                     (*(volatile unsigned short int *) 0x40005070)
#define          LINFID_A                                   0x40005070
// Variant ID
#define          LINVID                                     (*(volatile unsigned char      *) 0x40005074)
#define          LINVID_A                                   0x40005074
// Supplier ID
#define          LINSUPID                                   (*(volatile unsigned short int *) 0x40005078)
#define          LINSUPID_A                                 0x40005078
// Service ID
#define          LINSID                                     (*(volatile unsigned char      *) 0x4000507C)
#define          LINSID_A                                   0x4000507C

// LIN Calibration

#define          LIN_CALBASE                                (*(volatile unsigned long      *) 0x40005C00)
#define          LIN_CALBASE_A                              0x40005C00
// LIN calibration control
#define          LINCALCON                                  (*(volatile unsigned char      *) 0x40005C00)
#define          LINCALCON_A                                0x40005C00
#if           ALLOW_DEPRECATED_NAMES
// "LCALCTL" has been deprecated. Use "LINCALCON" instead.
#define          LCALCTL                                    (*(volatile unsigned char      *) 0x40005C00)
#define          LCALCTL_A                                  0x40005C00
#endif
// User calibration value (low precision mode)
#define          LINCALVAL0                                 (*(volatile unsigned short int *) 0x40005C04)
#define          LINCALVAL0_A                               0x40005C04
#if           ALLOW_DEPRECATED_NAMES
// "LCALVAL0" has been deprecated. Use "LINCALVAL0" instead.
#define          LCALVAL0                                   (*(volatile unsigned short int *) 0x40005C04)
#define          LCALVAL0_A                                 0x40005C04
#endif
// User calibration value (high precision mode)
#define          LINCALVAL1                                 (*(volatile unsigned short int *) 0x40005C08)
#define          LINCALVAL1_A                               0x40005C08
#if           ALLOW_DEPRECATED_NAMES
// "LCALVAL1" has been deprecated. Use "LINCALVAL1" instead.
#define          LCALVAL1                                   (*(volatile unsigned short int *) 0x40005C08)
#define          LCALVAL1_A                                 0x40005C08
#endif
// Maximum control window [15:0]
#define          LINCALMAXL                                 (*(volatile unsigned short int *) 0x40005C0C)
#define          LINCALMAXL_A                               0x40005C0C
#if           ALLOW_DEPRECATED_NAMES
// "LCALMAXL" has been deprecated. Use "LINCALMAXL" instead.
#define          LCALMAXL                                   (*(volatile unsigned short int *) 0x40005C0C)
#define          LCALMAXL_A                                 0x40005C0C
#endif
// Maximum control window [18:16]
#define          LINCALMAXH                                 (*(volatile unsigned char      *) 0x40005C10)
#define          LINCALMAXH_A                               0x40005C10
#if           ALLOW_DEPRECATED_NAMES
// "LCALMAXH" has been deprecated. Use "LINCALMAXH" instead.
#define          LCALMAXH                                   (*(volatile unsigned char      *) 0x40005C10)
#define          LCALMAXH_A                                 0x40005C10
#endif
// Minimum control window [15:0]
#define          LINCALMINL                                 (*(volatile unsigned short int *) 0x40005C14)
#define          LINCALMINL_A                               0x40005C14
#if           ALLOW_DEPRECATED_NAMES
// "LCALMINL" has been deprecated. Use "LINCALMINL" instead.
#define          LCALMINL                                   (*(volatile unsigned short int *) 0x40005C14)
#define          LCALMINL_A                                 0x40005C14
#endif
// Minimum control window [18:16]
#define          LINCALMINH                                 (*(volatile unsigned short int *) 0x40005C18)
#define          LINCALMINH_A                               0x40005C18
#if           ALLOW_DEPRECATED_NAMES
// "LCALMINH" has been deprecated. Use "LINCALMINH" instead.
#define          LCALMINH                                   (*(volatile unsigned short int *) 0x40005C18)
#define          LCALMINH_A                                 0x40005C18
#endif
// System calibration status
#define          LINCALSTA                                  (*(volatile unsigned short int *) 0x40005C1C)
#define          LINCALSTA_A                                0x40005C1C
#if           ALLOW_DEPRECATED_NAMES
// "LCALSTA" has been deprecated. Use "LINCALSTA" instead.
#define          LCALSTA                                    (*(volatile unsigned short int *) 0x40005C1C)
#define          LCALSTA_A                                  0x40005C1C
#endif
// System calibration value (low precision mode)
#define          LINCALVAL2                                 (*(volatile unsigned short int *) 0x40005C20)
#define          LINCALVAL2_A                               0x40005C20
#if           ALLOW_DEPRECATED_NAMES
// "LCALVAL2" has been deprecated. Use "LINCALVAL2" instead.
#define          LCALVAL2                                   (*(volatile unsigned short int *) 0x40005C20)
#define          LCALVAL2_A                                 0x40005C20
#endif
// System calibration value (high precision mode)
#define          LINCALVAL3                                 (*(volatile unsigned short int *) 0x40005C24)
#define          LINCALVAL3_A                               0x40005C24
#if           ALLOW_DEPRECATED_NAMES
// "LCALVAL3" has been deprecated. Use "LINCALVAL3" instead.
#define          LCALVAL3                                   (*(volatile unsigned short int *) 0x40005C24)
#define          LCALVAL3_A                                 0x40005C24
#endif
// Calibration lock
#define          LINCALOCK                                  (*(volatile unsigned short int *) 0x40005C28)
#define          LINCALOCK_A                                0x40005C28
#if           ALLOW_DEPRECATED_NAMES
// "LCALOCK" has been deprecated. Use "LINCALOCK" instead.
#define          LCALOCK                                    (*(volatile unsigned short int *) 0x40005C28)
#define          LCALOCK_A                                  0x40005C28
#endif

// GPIO

#define          GPIOBASE                                   (*(volatile unsigned long      *) 0x40006000)
#define          GPIOBASE_A                                 0x40006000
// GPIO Port 0 configuration
#define          GP0CON                                     (*(volatile unsigned short int *) 0x40006000)
#define          GP0CON_A                                   0x40006000
// GPIO Port 0 output enable
#define          GP0OEN                                     (*(volatile unsigned char      *) 0x40006004)
#define          GP0OEN_A                                   0x40006004
// GPIO Port 0 output pull up enable
#define          GP0PUL                                     (*(volatile unsigned char      *) 0x40006008)
#define          GP0PUL_A                                   0x40006008
// GPIO Port 0 open circuit enable
#define          GP0OCE                                     (*(volatile unsigned char      *) 0x4000600C)
#define          GP0OCE_A                                   0x4000600C
#if           ALLOW_DEPRECATED_NAMES
// "GP0ODE" has been deprecated. Use "GP0OCE" instead.
#define          GP0ODE                                     (*(volatile unsigned char      *) 0x4000600C)
#define          GP0ODE_A                                   0x4000600C
#endif
// GPIO Port 0 input data
#define          GP0INR                                     (*(volatile unsigned char      *) 0x40006014)
#define          GP0INR_A                                   0x40006014
// GPIO Port 0 data out
#define          GP0OUT                                     (*(volatile unsigned char      *) 0x40006018)
#define          GP0OUT_A                                   0x40006018
// GPIO Port 0 data out set
#define          GP0SET                                     (*(volatile unsigned char      *) 0x4000601C)
#define          GP0SET_A                                   0x4000601C
// GPIO Port 0 data out clear
#define          GP0CLR                                     (*(volatile unsigned char      *) 0x40006020)
#define          GP0CLR_A                                   0x40006020
// GPIO Port 0 pin toggle
#define          GP0TGL                                     (*(volatile unsigned char      *) 0x40006024)
#define          GP0TGL_A                                   0x40006024
#if           ALLOW_DEPRECATED_NAMES
// "GP0TOG" has been deprecated. Use "GP0TGL" instead.
#define          GP0TOG                                     (*(volatile unsigned char      *) 0x40006024)
#define          GP0TOG_A                                   0x40006024
#endif

// Analog Interface Block

#define          ANABASE                                    (*(volatile unsigned long      *) 0x40008800)
#define          ANABASE_A                                  0x40008800
// Internal 1.2V Reference Control
#define          HRFCTRL                                    (*(volatile unsigned short int *) 0x40008808)
#define          HRFCTRL_A                                  0x40008808
// Internal Reference Buffer Power Down
#define          IRFPD                                      (*(volatile unsigned short int *) 0x40008824)
#define          IRFPD_A                                    0x40008824

// LFOSC trim

#define          TRMBASE                                    (*(volatile unsigned long      *) 0x40009C00)
#define          TRMBASE_A                                  0x40009C00
// Status
#define          TRMSTA                                     (*(volatile unsigned char      *) 0x40009C00)
#define          TRMSTA_A                                   0x40009C00
// Control
#define          TRMCON                                     (*(volatile unsigned char      *) 0x40009C04)
#define          TRMCON_A                                   0x40009C04
// Maximum calibration value
#define          TRMMXC                                     (*(volatile unsigned char      *) 0x40009C08)
#define          TRMMXC_A                                   0x40009C08
// Minimum calibration value
#define          TRMMNC                                     (*(volatile unsigned char      *) 0x40009C0C)
#define          TRMMNC_A                                   0x40009C0C
// Oscillator trim value
#define          TRMVAL                                     (*(volatile unsigned char      *) 0x40009C10)
#define          TRMVAL_A                                   0x40009C10
// LFOSC target count
#define          TRM32TGT                                   (*(volatile unsigned char      *) 0x40009C14)
#define          TRM32TGT_A                                 0x40009C14
// LFOSC current count
#define          TRM32CNT                                   (*(volatile unsigned char      *) 0x40009C18)
#define          TRM32CNT_A                                 0x40009C18
// UCLK target count
#define          TRMUCTGT                                   (*(volatile unsigned short int *) 0x40009C1C)
#define          TRMUCTGT_A                                 0x40009C1C
// UCLK current count
#define          TRMUCCNT                                   (*(volatile unsigned short int *) 0x40009C20)
#define          TRMUCCNT_A                                 0x40009C20

// Flash Controller

#define          FEEBASE                                    (*(volatile unsigned long      *) 0x40018000)
#define          FEEBASE_A                                  0x40018000
// Status
#define          FEESTA                                     (*(volatile unsigned long      *) 0x40018000)
#define          FEESTA_A                                   0x40018000
#if           ALLOW_DEPRECATED_NAMES
// "FEE0STA" has been deprecated. Use "FEESTA" instead.
#define          FEE0STA                                    (*(volatile unsigned long      *) 0x40018000)
#define          FEE0STA_A                                  0x40018000
#endif
// Command Control
#define          FEECON0                                    (*(volatile unsigned short int *) 0x40018004)
#define          FEECON0_A                                  0x40018004
#if           ALLOW_DEPRECATED_NAMES
// "FEE0CON0" has been deprecated. Use "FEECON0" instead.
#define          FEE0CON0                                   (*(volatile unsigned short int *) 0x40018004)
#define          FEE0CON0_A                                 0x40018004
#endif
// Command
#define          FEECMD                                     (*(volatile unsigned long      *) 0x40018008)
#define          FEECMD_A                                   0x40018008
#if           ALLOW_DEPRECATED_NAMES
// "FEE0CMD" has been deprecated. Use "FEECMD" instead.
#define          FEE0CMD                                    (*(volatile unsigned long      *) 0x40018008)
#define          FEE0CMD_A                                  0x40018008
#endif
// Flash Address Keyhole Register
#define          FEEADR                                     (*(volatile unsigned long      *) 0x4001800C)
#define          FEEADR_A                                   0x4001800C
#if           ALLOW_DEPRECATED_NAMES
// "FEE0FLADR" has been deprecated. Use "FEEADR" instead.
#define          FEE0FLADR                                  (*(volatile unsigned long      *) 0x4001800C)
#define          FEE0FLADR_A                                0x4001800C
#endif
// Flash Data Register (Lower)
#define          FEEDATL                                    (*(volatile unsigned long      *) 0x40018010)
#define          FEEDATL_A                                  0x40018010
#if           ALLOW_DEPRECATED_NAMES
// "FEE0FLDATA0" has been deprecated. Use "FEEDATL" instead.
#define          FEE0FLDATA0                                (*(volatile unsigned long      *) 0x40018010)
#define          FEE0FLDATA0_A                              0x40018010
#endif
// Flash Data Register (Upper)
#define          FEEDATH                                    (*(volatile unsigned long      *) 0x40018014)
#define          FEEDATH_A                                  0x40018014
#if           ALLOW_DEPRECATED_NAMES
// "FEE0FLDATA1" has been deprecated. Use "FEEDATH" instead.
#define          FEE0FLDATA1                                (*(volatile unsigned long      *) 0x40018014)
#define          FEE0FLDATA1_A                              0x40018014
#endif
// Lower page address
#define          FEEADR1L                                   (*(volatile unsigned long      *) 0x40018018)
#define          FEEADR1L_A                                 0x40018018
#if           ALLOW_DEPRECATED_NAMES
// "FEE0PADR0" has been deprecated. Use "FEEADR1L" instead.
#define          FEE0PADR0                                  (*(volatile unsigned long      *) 0x40018018)
#define          FEE0PADR0_A                                0x40018018
// "FEEADRPL" has been deprecated. Use "FEEADR1L" instead.
#define          FEEADRPL                                   (*(volatile unsigned long      *) 0x40018018)
#define          FEEADRPL_A                                 0x40018018
#endif
// Upper page address
#define          FEEADR1H                                   (*(volatile unsigned long      *) 0x4001801C)
#define          FEEADR1H_A                                 0x4001801C
#if           ALLOW_DEPRECATED_NAMES
// "FEE0PADR1" has been deprecated. Use "FEEADR1H" instead.
#define          FEE0PADR1                                  (*(volatile unsigned long      *) 0x4001801C)
#define          FEE0PADR1_A                                0x4001801C
// "FEEADRPH" has been deprecated. Use "FEEADR1H" instead.
#define          FEEADRPH                                   (*(volatile unsigned long      *) 0x4001801C)
#define          FEEADRPH_A                                 0x4001801C
#endif
// Key
#define          FEEKEY                                     (*(volatile unsigned short int *) 0x40018020)
#define          FEEKEY_A                                   0x40018020
#if           ALLOW_DEPRECATED_NAMES
// "FEE0KEY" has been deprecated. Use "FEEKEY" instead.
#define          FEE0KEY                                    (*(volatile unsigned short int *) 0x40018020)
#define          FEE0KEY_A                                  0x40018020
#endif
// Program flash write protection
#define          FEEPROP                                    (*(volatile unsigned long      *) 0x40018028)
#define          FEEPROP_A                                  0x40018028
#if           ALLOW_DEPRECATED_NAMES
// "FEE0PROW" has been deprecated. Use "FEEPROP" instead.
#define          FEE0PROW                                   (*(volatile unsigned long      *) 0x40018028)
#define          FEE0PROW_A                                 0x40018028
// "FEE0PRO" has been deprecated. Use "FEEPROP" instead.
#define          FEE0PRO                                    (*(volatile unsigned long      *) 0x40018028)
#define          FEE0PRO_A                                  0x40018028
#endif
// Data flash write protection
#define          FEEPROD                                    (*(volatile unsigned char      *) 0x4001802C)
#define          FEEPROD_A                                  0x4001802C
#if           ALLOW_DEPRECATED_NAMES
// "FEE0PROWDT" has been deprecated. Use "FEEPROD" instead.
#define          FEE0PROWDT                                 (*(volatile unsigned char      *) 0x4001802C)
#define          FEE0PROWDT_A                               0x4001802C
// "FEE1PRO" has been deprecated. Use "FEEPROD" instead.
#define          FEE1PRO                                    (*(volatile unsigned char      *) 0x4001802C)
#define          FEE1PRO_A                                  0x4001802C
#endif
// Data flash ECC disable
#define          FEEECC                                     (*(volatile unsigned long      *) 0x40018030)
#define          FEEECC_A                                   0x40018030
#if           ALLOW_DEPRECATED_NAMES
// "FEE0ECCDIS" has been deprecated. Use "FEEECC" instead.
#define          FEE0ECCDIS                                 (*(volatile unsigned long      *) 0x40018030)
#define          FEE0ECCDIS_A                               0x40018030
// "ECC1DIS" has been deprecated. Use "FEEECC" instead.
#define          ECC1DIS                                    (*(volatile unsigned long      *) 0x40018030)
#define          ECC1DIS_A                                  0x40018030
#endif
// Signature
#define          FEESIGN                                    (*(volatile unsigned long      *) 0x40018034)
#define          FEESIGN_A                                  0x40018034
#if           ALLOW_DEPRECATED_NAMES
// "FEE0SIGL" has been deprecated. Use "FEESIGN" instead.
#define          FEE0SIGL                                   (*(volatile unsigned long      *) 0x40018034)
#define          FEE0SIGL_A                                 0x40018034
// "FEESIG" has been deprecated. Use "FEESIGN" instead.
#define          FEESIG                                     (*(volatile unsigned long      *) 0x40018034)
#define          FEESIG_A                                   0x40018034
#endif
// Serial Wire Control
#define          FEECON1                                    (*(volatile unsigned char      *) 0x40018038)
#define          FEECON1_A                                  0x40018038
#if           ALLOW_DEPRECATED_NAMES
// "FEE0CON1" has been deprecated. Use "FEECON1" instead.
#define          FEE0CON1                                   (*(volatile unsigned char      *) 0x40018038)
#define          FEE0CON1_A                                 0x40018038
#endif
// Write abort address
#define          FEEABORT                                   (*(volatile unsigned long      *) 0x40018040)
#define          FEEABORT_A                                 0x40018040
#if           ALLOW_DEPRECATED_NAMES
// "FEE0ADRA" has been deprecated. Use "FEEABORT" instead.
#define          FEE0ADRA                                   (*(volatile unsigned long      *) 0x40018040)
#define          FEE0ADRA_A                                 0x40018040
// "FEEADRA" has been deprecated. Use "FEEABORT" instead.
#define          FEEADRA                                    (*(volatile unsigned long      *) 0x40018040)
#define          FEEADRA_A                                  0x40018040
#endif
// Abort enable register
#define          FEEAEN0                                    (*(volatile unsigned short int *) 0x40018048)
#define          FEEAEN0_A                                  0x40018048
#if           ALLOW_DEPRECATED_NAMES
// "FEE0AEN0" has been deprecated. Use "FEEAEN0" instead.
#define          FEE0AEN0                                   (*(volatile unsigned short int *) 0x40018048)
#define          FEE0AEN0_A                                 0x40018048
// "FEE0AENL" has been deprecated. Use "FEEAEN0" instead.
#define          FEE0AENL                                   (*(volatile unsigned short int *) 0x40018048)
#define          FEE0AENL_A                                 0x40018048
#endif
// User FAA Key Low.
#define          USERFAKEY0                                 (*(volatile unsigned long      *) 0x40018068)
#define          USERFAKEY0_A                               0x40018068
#if           ALLOW_DEPRECATED_NAMES
// "FEE0FAA0" has been deprecated. Use "USERFAKEY0" instead.
#define          FEE0FAA0                                   (*(volatile unsigned long      *) 0x40018068)
#define          FEE0FAA0_A                                 0x40018068
// "FEEFAAL" has been deprecated. Use "USERFAKEY0" instead.
#define          FEEFAAL                                    (*(volatile unsigned long      *) 0x40018068)
#define          FEEFAAL_A                                  0x40018068
#endif
// User FAA Key High
#define          USERFAKEY1                                 (*(volatile unsigned long      *) 0x4001806C)
#define          USERFAKEY1_A                               0x4001806C
#if           ALLOW_DEPRECATED_NAMES
// "FEE0FAA1" has been deprecated. Use "USERFAKEY1" instead.
#define          FEE0FAA1                                   (*(volatile unsigned long      *) 0x4001806C)
#define          FEE0FAA1_A                                 0x4001806C
// "FEEFAAH" has been deprecated. Use "USERFAKEY1" instead.
#define          FEEFAAH                                    (*(volatile unsigned long      *) 0x4001806C)
#define          FEEFAAH_A                                  0x4001806C
#endif
// Program flash address for ECC error
#define          FEEPECC                                    (*(volatile unsigned long      *) 0x40018074)
#define          FEEPECC_A                                  0x40018074
#if           ALLOW_DEPRECATED_NAMES
// "FEE0ECCADR0" has been deprecated. Use "FEEPECC" instead.
#define          FEE0ECCADR0                                (*(volatile unsigned long      *) 0x40018074)
#define          FEE0ECCADR0_A                              0x40018074
// "ECC0ERRA" has been deprecated. Use "FEEPECC" instead.
#define          ECC0ERRA                                   (*(volatile unsigned long      *) 0x40018074)
#define          ECC0ERRA_A                                 0x40018074
#endif
// Data flash address for ECC error
#define          FEEDECC                                    (*(volatile unsigned long      *) 0x40018078)
#define          FEEDECC_A                                  0x40018078
#if           ALLOW_DEPRECATED_NAMES
// "FEE0ECCADR1" has been deprecated. Use "FEEDECC" instead.
#define          FEE0ECCADR1                                (*(volatile unsigned long      *) 0x40018078)
#define          FEE0ECCADR1_A                              0x40018078
// "ECC1ERRA" has been deprecated. Use "FEEDECC" instead.
#define          ECC1ERRA                                   (*(volatile unsigned long      *) 0x40018078)
#define          ECC1ERRA_A                                 0x40018078
#endif

// ADC

#define          ADCBASE                                    (*(volatile unsigned long      *) 0x40030000)
#define          ADCBASE_A                                  0x40030000
// Status
#define          ADCSTA                                     (*(volatile unsigned short int *) 0x40030000)
#define          ADCSTA_A                                   0x40030000
// ADC Interrupt Mask register
#define          ADCMSKI                                    (*(volatile unsigned char      *) 0x40030004)
#define          ADCMSKI_A                                  0x40030004
// Mode control
#define          ADCMDE                                     (*(volatile unsigned char      *) 0x40030008)
#define          ADCMDE_A                                   0x40030008
// Current ADC control
#define          ADC0CON                                    (*(volatile unsigned long      *) 0x4003000C)
#define          ADC0CON_A                                  0x4003000C
// Voltage Temperature ADC control
#define          ADC1CON                                    (*(volatile unsigned long      *) 0x40030010)
#define          ADC1CON_A                                  0x40030010
// Filter configuration
#define          ADCFLT                                     (*(volatile unsigned long      *) 0x40030018)
#define          ADCFLT_A                                   0x40030018
// Configuration
#define          ADCCFG                                     (*(volatile unsigned short int *) 0x4003001C)
#define          ADCCFG_A                                   0x4003001C
// Current ADC result
#define          ADC0DAT                                    (*(volatile unsigned long      *) 0x40030020)
#define          ADC0DAT_A                                  0x40030020
// Voltage Temperature ADC result
#define          ADC1DAT                                    (*(volatile unsigned long      *) 0x40030024)
#define          ADC1DAT_A                                  0x40030024
// Current ADC offset calibration
#define          ADC0OF                                     (*(volatile unsigned long      *) 0x40030030)
#define          ADC0OF_A                                   0x40030030
// Voltage ADC offset calibration
#define          ADC1OF                                     (*(volatile unsigned long      *) 0x40030034)
#define          ADC1OF_A                                   0x40030034
// Temperature ADC offset calibration
#define          ADC2OF                                     (*(volatile unsigned long      *) 0x40030038)
#define          ADC2OF_A                                   0x40030038
// Current ADC gain calibration
#define          ADC0GN                                     (*(volatile unsigned long      *) 0x4003003C)
#define          ADC0GN_A                                   0x4003003C
// Voltage ADC gain calibration
#define          ADC1GN                                     (*(volatile unsigned long      *) 0x40030040)
#define          ADC1GN_A                                   0x40030040
// Temperature ADC gain calibration
#define          ADC2GN                                     (*(volatile unsigned long      *) 0x40030044)
#define          ADC2GN_A                                   0x40030044
// Result counter limit
#define          ADC0RCL                                    (*(volatile unsigned short int *) 0x40030048)
#define          ADC0RCL_A                                  0x40030048
// Result-counter value
#define          ADC0RCV                                    (*(volatile unsigned short int *) 0x4003004C)
#define          ADC0RCV_A                                  0x4003004C
// Current ADC comparator threshold
#define          ADC0TH                                     (*(volatile unsigned long      *) 0x40030050)
#define          ADC0TH_A                                   0x40030050
// Comparator threshold counter limit
#define          ADC0THC                                    (*(volatile unsigned char      *) 0x40030054)
#define          ADC0THC_A                                  0x40030054
// Comparator threshold counter value
#define          ADC0THV                                    (*(volatile unsigned char      *) 0x40030058)
#define          ADC0THV_A                                  0x40030058
// Current ADC accumulator
#define          ADC0ACC                                    (*(volatile unsigned long      *) 0x4003005C)
#define          ADC0ACC_A                                  0x4003005C
// Current ADC accumulator threshold
#define          ADC0ATH                                    (*(volatile unsigned long      *) 0x40030060)
#define          ADC0ATH_A                                  0x40030060

// NVIC

#define          NVICBASE                                   (*(volatile unsigned long      *) 0xE000E000)
#define          NVICBASE_A                                 0xE000E000
// Interrupt Control Type
#define          ICTR                                       (*(volatile unsigned char      *) 0xE000E004)
#define          ICTR_A                                     0xE000E004
#if           ALLOW_DEPRECATED_NAMES
// "INTNUM" has been deprecated. Use "ICTR" instead.
#define          INTNUM                                     (*(volatile unsigned char      *) 0xE000E004)
#define          INTNUM_A                                   0xE000E004
#endif
// SysTick Control and Status
#define          STCSR                                      (*(volatile unsigned long      *) 0xE000E010)
#define          STCSR_A                                    0xE000E010
#if           ALLOW_DEPRECATED_NAMES
// "STKSTA" has been deprecated. Use "STCSR" instead.
#define          STKSTA                                     (*(volatile unsigned long      *) 0xE000E010)
#define          STKSTA_A                                   0xE000E010
#endif
// SysTick Reload Value
#define          STRVR                                      (*(volatile unsigned long      *) 0xE000E014)
#define          STRVR_A                                    0xE000E014
#if           ALLOW_DEPRECATED_NAMES
// "STKLD" has been deprecated. Use "STRVR" instead.
#define          STKLD                                      (*(volatile unsigned long      *) 0xE000E014)
#define          STKLD_A                                    0xE000E014
#endif
// SysTick Current Value
#define          STCVR                                      (*(volatile unsigned long      *) 0xE000E018)
#define          STCVR_A                                    0xE000E018
#if           ALLOW_DEPRECATED_NAMES
// "STKVAL" has been deprecated. Use "STCVR" instead.
#define          STKVAL                                     (*(volatile unsigned long      *) 0xE000E018)
#define          STKVAL_A                                   0xE000E018
#endif
// SysTick Calibration Value
#define          STCR                                       (*(volatile unsigned long      *) 0xE000E01C)
#define          STCR_A                                     0xE000E01C
#if           ALLOW_DEPRECATED_NAMES
// "STKCAL" has been deprecated. Use "STCR" instead.
#define          STKCAL                                     (*(volatile unsigned long      *) 0xE000E01C)
#define          STKCAL_A                                   0xE000E01C
#endif
// IRQ0..13 Set_Enable
#define          ISER0                                      (*(volatile unsigned long      *) 0xE000E100)
#define          ISER0_A                                    0xE000E100
#if           ALLOW_DEPRECATED_NAMES
// "INTSETE0" has been deprecated. Use "ISER0" instead.
#define          INTSETE0                                   (*(volatile unsigned long      *) 0xE000E100)
#define          INTSETE0_A                                 0xE000E100
#endif
// IRQ0..13 Clear_Enable
#define          ICER0                                      (*(volatile unsigned long      *) 0xE000E180)
#define          ICER0_A                                    0xE000E180
#if           ALLOW_DEPRECATED_NAMES
// "INTCLRE0" has been deprecated. Use "ICER0" instead.
#define          INTCLRE0                                   (*(volatile unsigned long      *) 0xE000E180)
#define          INTCLRE0_A                                 0xE000E180
#endif
// IRQ0..13 Set_Pending
#define          INTSETP0                                   (*(volatile unsigned long      *) 0xE000E200)
#define          INTSETP0_A                                 0xE000E200
// IRQ0..13 Clear_Pending
#define          ICPR0                                      (*(volatile unsigned long      *) 0xE000E280)
#define          ICPR0_A                                    0xE000E280
#if           ALLOW_DEPRECATED_NAMES
// "INTCLRP0" has been deprecated. Use "ICPR0" instead.
#define          INTCLRP0                                   (*(volatile unsigned long      *) 0xE000E280)
#define          INTCLRP0_A                                 0xE000E280
#endif
// IRQ0..13 Active Bit
#define          IABR0                                      (*(volatile unsigned long      *) 0xE000E300)
#define          IABR0_A                                    0xE000E300
#if           ALLOW_DEPRECATED_NAMES
// "INTACT0" has been deprecated. Use "IABR0" instead.
#define          INTACT0                                    (*(volatile unsigned long      *) 0xE000E300)
#define          INTACT0_A                                  0xE000E300
#endif
// IRQ0..3 Priority
#define          IPR0                                       (*(volatile unsigned long      *) 0xE000E400)
#define          IPR0_A                                     0xE000E400
#if           ALLOW_DEPRECATED_NAMES
// "INTPRI0" has been deprecated. Use "IPR0" instead.
#define          INTPRI0                                    (*(volatile unsigned long      *) 0xE000E400)
#define          INTPRI0_A                                  0xE000E400
#endif
// IRQ4..7 Priority
#define          IPR1                                       (*(volatile unsigned long      *) 0xE000E404)
#define          IPR1_A                                     0xE000E404
#if           ALLOW_DEPRECATED_NAMES
// "INTPRI1" has been deprecated. Use "IPR1" instead.
#define          INTPRI1                                    (*(volatile unsigned long      *) 0xE000E404)
#define          INTPRI1_A                                  0xE000E404
#endif
// IRQ8..11 Priority
#define          IPR2                                       (*(volatile unsigned long      *) 0xE000E408)
#define          IPR2_A                                     0xE000E408
#if           ALLOW_DEPRECATED_NAMES
// "INTPRI2" has been deprecated. Use "IPR2" instead.
#define          INTPRI2                                    (*(volatile unsigned long      *) 0xE000E408)
#define          INTPRI2_A                                  0xE000E408
#endif
// IRQ12..13 Priority
#define          IPR3                                       (*(volatile unsigned long      *) 0xE000E40C)
#define          IPR3_A                                     0xE000E40C
#if           ALLOW_DEPRECATED_NAMES
// "INTPRI3" has been deprecated. Use "IPR3" instead.
#define          INTPRI3                                    (*(volatile unsigned long      *) 0xE000E40C)
#define          INTPRI3_A                                  0xE000E40C
#endif
// CPUID Base
#define          CPUID                                      (*(volatile unsigned long      *) 0xE000ED00)
#define          CPUID_A                                    0xE000ED00
#if           ALLOW_DEPRECATED_NAMES
// "INTCPID" has been deprecated. Use "CPUID" instead.
#define          INTCPID                                    (*(volatile unsigned long      *) 0xE000ED00)
#define          INTCPID_A                                  0xE000ED00
#endif
// Interrupt Control State
#define          ICSR                                       (*(volatile unsigned long      *) 0xE000ED04)
#define          ICSR_A                                     0xE000ED04
#if           ALLOW_DEPRECATED_NAMES
// "INTSTA" has been deprecated. Use "ICSR" instead.
#define          INTSTA                                     (*(volatile unsigned long      *) 0xE000ED04)
#define          INTSTA_A                                   0xE000ED04
#endif
// Vector Table Offset
#define          VTOR                                       (*(volatile unsigned long      *) 0xE000ED08)
#define          VTOR_A                                     0xE000ED08
#if           ALLOW_DEPRECATED_NAMES
// "INTVEC" has been deprecated. Use "VTOR" instead.
#define          INTVEC                                     (*(volatile unsigned long      *) 0xE000ED08)
#define          INTVEC_A                                   0xE000ED08
#endif
// Application Interrupt and Reset Control
#define          AIRCR                                      (*(volatile unsigned long      *) 0xE000ED0C)
#define          AIRCR_A                                    0xE000ED0C
#if           ALLOW_DEPRECATED_NAMES
// "INTAIRC" has been deprecated. Use "AIRCR" instead.
#define          INTAIRC                                    (*(volatile unsigned long      *) 0xE000ED0C)
#define          INTAIRC_A                                  0xE000ED0C
#endif
// System Control
#define          SCR                                        (*(volatile unsigned long      *) 0xE000ED10)
#define          SCR_A                                      0xE000ED10
#if           ALLOW_DEPRECATED_NAMES
// "INTCON0" has been deprecated. Use "SCR" instead.
#define          INTCON0                                    (*(volatile unsigned long      *) 0xE000ED10)
#define          INTCON0_A                                  0xE000ED10
#endif
// Configuration Control
#define          CCR                                        (*(volatile unsigned long      *) 0xE000ED14)
#define          CCR_A                                      0xE000ED14
#if           ALLOW_DEPRECATED_NAMES
// "INTCON1" has been deprecated. Use "CCR" instead.
#define          INTCON1                                    (*(volatile unsigned long      *) 0xE000ED14)
#define          INTCON1_A                                  0xE000ED14
#endif
// System Handler Priority  1
#define          SHPR1                                      (*(volatile unsigned long      *) 0xE000ED18)
#define          SHPR1_A                                    0xE000ED18
#if           ALLOW_DEPRECATED_NAMES
// "INTSHPRIO0" has been deprecated. Use "SHPR1" instead.
#define          INTSHPRIO0                                 (*(volatile unsigned long      *) 0xE000ED18)
#define          INTSHPRIO0_A                               0xE000ED18
#endif
// System Handler Priority  2
#define          SHPR2                                      (*(volatile unsigned long      *) 0xE000ED1C)
#define          SHPR2_A                                    0xE000ED1C
#if           ALLOW_DEPRECATED_NAMES
// "INTSHPRIO1" has been deprecated. Use "SHPR2" instead.
#define          INTSHPRIO1                                 (*(volatile unsigned long      *) 0xE000ED1C)
#define          INTSHPRIO1_A                               0xE000ED1C
#endif
// System Handler Priority  3
#define          SHPR3                                      (*(volatile unsigned long      *) 0xE000ED20)
#define          SHPR3_A                                    0xE000ED20
#if           ALLOW_DEPRECATED_NAMES
// "INTSHPRIO2" has been deprecated. Use "SHPR3" instead.
#define          INTSHPRIO2                                 (*(volatile unsigned long      *) 0xE000ED20)
#define          INTSHPRIO2_A                               0xE000ED20
#endif
// System Handler Control and State
#define          SHCSR                                      (*(volatile unsigned long      *) 0xE000ED24)
#define          SHCSR_A                                    0xE000ED24
#if           ALLOW_DEPRECATED_NAMES
// "INTSHCSR" has been deprecated. Use "SHCSR" instead.
#define          INTSHCSR                                   (*(volatile unsigned long      *) 0xE000ED24)
#define          INTSHCSR_A                                 0xE000ED24
// "INTSHCS" has been deprecated. Use "SHCSR" instead.
#define          INTSHCS                                    (*(volatile unsigned long      *) 0xE000ED24)
#define          INTSHCS_A                                  0xE000ED24
#endif
// Configurable Fault Status
#define          CFSR                                       (*(volatile unsigned long      *) 0xE000ED28)
#define          CFSR_A                                     0xE000ED28
#if           ALLOW_DEPRECATED_NAMES
// "INTCFSR" has been deprecated. Use "CFSR" instead.
#define          INTCFSR                                    (*(volatile unsigned long      *) 0xE000ED28)
#define          INTCFSR_A                                  0xE000ED28
// "INTCFS" has been deprecated. Use "CFSR" instead.
#define          INTCFS                                     (*(volatile unsigned long      *) 0xE000ED28)
#define          INTCFS_A                                   0xE000ED28
#endif
// Hard Fault Status
#define          HFSR                                       (*(volatile unsigned long      *) 0xE000ED2C)
#define          HFSR_A                                     0xE000ED2C
#if           ALLOW_DEPRECATED_NAMES
// "INTHFSR" has been deprecated. Use "HFSR" instead.
#define          INTHFSR                                    (*(volatile unsigned long      *) 0xE000ED2C)
#define          INTHFSR_A                                  0xE000ED2C
// "INTHFS" has been deprecated. Use "HFSR" instead.
#define          INTHFS                                     (*(volatile unsigned long      *) 0xE000ED2C)
#define          INTHFS_A                                   0xE000ED2C
#endif
// Mem Manage Address
#define          MMFAR                                      (*(volatile unsigned long      *) 0xE000ED34)
#define          MMFAR_A                                    0xE000ED34
#if           ALLOW_DEPRECATED_NAMES
// "INTMMAR" has been deprecated. Use "MMFAR" instead.
#define          INTMMAR                                    (*(volatile unsigned long      *) 0xE000ED34)
#define          INTMMAR_A                                  0xE000ED34
// "INTMMA" has been deprecated. Use "MMFAR" instead.
#define          INTMMA                                     (*(volatile unsigned long      *) 0xE000ED34)
#define          INTMMA_A                                   0xE000ED34
#endif
// Bus Fault Address
#define          BFAR                                       (*(volatile unsigned long      *) 0xE000ED38)
#define          BFAR_A                                     0xE000ED38
#if           ALLOW_DEPRECATED_NAMES
// "INTBFAR" has been deprecated. Use "BFAR" instead.
#define          INTBFAR                                    (*(volatile unsigned long      *) 0xE000ED38)
#define          INTBFAR_A                                  0xE000ED38
// "INTBFA" has been deprecated. Use "BFAR" instead.
#define          INTBFA                                     (*(volatile unsigned long      *) 0xE000ED38)
#define          INTBFA_A                                   0xE000ED38
#endif
// Software Trigger Interrupt
#define          STIR                                       (*(volatile unsigned long      *) 0xE000EF00)
#define          STIR_A                                     0xE000EF00
#if           ALLOW_DEPRECATED_NAMES
// "INTTRGI" has been deprecated. Use "STIR" instead.
#define          INTTRGI                                    (*(volatile unsigned long      *) 0xE000EF00)
#define          INTTRGI_A                                  0xE000EF00
// "INTSTI" has been deprecated. Use "STIR" instead.
#define          INTSTI                                     (*(volatile unsigned long      *) 0xE000EF00)
#define          INTSTI_A                                   0xE000EF00
#endif

/** @} */ /* End of group Device_Peripheral_Registers */
/** @} */ /* End of group ADUCM342 */
/** @} */ /* End of group CMSIS */

#ifdef __cplusplus
}
#endif


#endif  // __ADUCM342_H__
