;******************************************************************************
;
; THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES INC. ``AS IS'' AND ANY EXPRESS OR
; IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
; MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT, ARE
; DISCLAIMED. IN NO EVENT SHALL ANALOG DEVICES INC. BE LIABLE FOR ANY DIRECT,
; INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
; ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
; POSSIBILITY OF SUCH DAMAGE.
;
; YOU ASSUME ANY AND ALL RISK FROM THE USE OF THIS CODE OR SUPPORT FILE.
;
; IT IS THE RESPONSIBILITY OF THE PERSON INTEGRATING THIS CODE INTO AN
; APPLICATION TO ENSURE THAT THE RESULTING APPLICATION PERFORMS AS REQUIRED
; AND IS SAFE.
;
;    Module       : startup_ADuCM342.s
;    Description  : Cortex-M3 startup file - ADuCM342 Version
;    Date         : Jan 2023
;    Version      : v1.00
;    Changelog    : v1.00 Initial
;
;
;******************************************************************************

;******************************************************************************
;
; <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
;
;******************************************************************************
Stack   EQU     0x00000100

;******************************************************************************
;
; <o> Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
;
;******************************************************************************
Heap    EQU     0x00000000

;******************************************************************************
;
; Allocate space for the stack.
;
;******************************************************************************
        AREA    STACK, NOINIT, READWRITE, ALIGN=3
StackMem
        SPACE   Stack
__initial_sp

;******************************************************************************
;
; Allocate space for the heap.
;
;******************************************************************************
        AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
HeapMem
        SPACE   Heap
__heap_limit

;******************************************************************************
;
; Indicate that the code in this file preserves 8-byte alignment of the stack.
;
;******************************************************************************
        PRESERVE8

;******************************************************************************
;
; Place code into the reset code section.
;
;******************************************************************************
        AREA    RESET, CODE, READONLY
        THUMB

;******************************************************************************
;
; The vector table.
;
;******************************************************************************
		EXTERN SysTick_Int_Handler	
		EXTERN GP_Tmr_Int_Handler	
		EXTERN ADC_Int_Handler		
		EXTERN WakeUp_Int_Handler	
		EXTERN LIN0_Int_Handler		
		EXTERN LIN1_Int_Handler		
		EXTERN LIN2_Int_Handler		
		EXTERN Hard_Fault_Exception	
	
        EXPORT  __Vectors
__Vectors
        DCD     StackMem + Stack            ; Top of Stack
        DCD     Reset_Handler               ; Reset Handler
        DCD     NmiSR                       ; NMI Handler
        DCD     Hard_Fault_Exception        ; Hard Fault Handler
        DCD     MEMDefaultHandler           ; MPU Fault Handler
        DCD     BUSDefaultHandler           ; Bus Fault Handler
        DCD     USGDefaultHandler           ; Usage Fault Handler
        DCD     0                           ; Reserved
        DCD     0                           ; Reserved
        DCD     0                           ; Reserved
        DCD     0                           ; Reserved
        DCD     IntDefaultHandler           ; SVCall Handler
        DCD     IntDefaultHandler           ; Debug Monitor Handler
        DCD     0                           ; Reserved
        DCD     IntDefaultHandler           ; PendSV Handler
        DCD     SysTick_Int_Handler         ; SysTick Handler

        DCD     WakeUp_Int_Handler          ; Wake Up Timer 		[ 0]
        DCD     IntDefaultHandler           ; External Interrupt 0	[ 1]
        DCD     IntDefaultHandler           ; External Interrupt 1	[ 2]
        DCD     IntDefaultHandler           ; Watch Dog Timer		[ 3]
        DCD     GP_Tmr_Int_Handler          ; General Purpose Timer	[ 4]
        DCD     ADC_Int_Handler             ; ADC					[ 5]
        DCD     IntDefaultHandler           ; FLASH Controller		[ 6]
        DCD     IntDefaultHandler           ; SPI					[ 7]
        DCD     LIN0_Int_Handler            ; LIN 0					[ 8]
        DCD     LIN1_Int_Handler            ; LIN 1					[ 9]
        DCD     LIN2_Int_Handler            ; LIN 2					[10]
        DCD     IntDefaultHandler           ; 2WI					[11]
        DCD     IntDefaultHandler           ; CALOSC				[12]
        DCD     IntDefaultHandler           ; SRAM ECC				[13]

;******************************************************************************
;
; This is the code that gets called when the processor first starts execution
; following a reset event.
;
;******************************************************************************
        EXPORT  Reset_Handler
Reset_Handler
        ;
        ; Call the C library enty point that handles startup.  This will copy
        ; the .data section initializers from flash to SRAM and zero fill the
        ; .bss section.
        ;
        IMPORT  __main
        B       __main

;******************************************************************************
;
; This is the code that gets called when the processor receives a NMI.  This
; simply enters an infinite loop, preserving the system state for examination
; by a debugger.
;
;******************************************************************************
NmiSR
        B       NmiSR

;******************************************************************************
;
; This is the code that gets called when the processor receives a fault
; interrupt.  This simply enters an infinite loop, preserving the system state
; for examination by a debugger.
;
;******************************************************************************
FaultISR
        B       FaultISR

;******************************************************************************
;
; This is the code that gets called when the processor receives an Szstem Tick
; Interrupt.  This simply enters an infinite loop, preserving the system state
; for examination by a debugger.
;
;******************************************************************************
SysTickIntrHandler
		B		SysTickIntrHandler

;******************************************************************************
;
; This is the code that gets called when the processor receives an unexpected
; interrupt.  This simply enters an infinite loop, preserving the system state
; for examination by a debugger.
;
;******************************************************************************
IntDefaultHandler
        B       IntDefaultHandler
		
MEMDefaultHandler
        B       MEMDefaultHandler	
		
BUSDefaultHandler
        B       BUSDefaultHandler	
		
USGDefaultHandler
        B       USGDefaultHandler
		

;******************************************************************************
;
; Make sure the end of this section is aligned.
;
;******************************************************************************
        ALIGN

;******************************************************************************
;
; Some code in the normal code section for initializing the heap and stack.
;
;******************************************************************************
        AREA    |.text|, CODE, READONLY

;******************************************************************************
;
; The function expected of the C library startup code for defining the stack
; and heap memory locations.  For the C library version of the startup code,
; provide this function so that the C library initialization code can find out
; the location of the stack and heap.
;
;******************************************************************************
    IF :DEF: __MICROLIB
        EXPORT  __initial_sp
        EXPORT  __heap_base
        EXPORT __heap_limit
    ELSE
        IMPORT  __use_two_region_memory
        EXPORT  __user_initial_stackheap
__user_initial_stackheap
        LDR     R0, =HeapMem
        LDR     R1, =(StackMem + Stack)
        LDR     R2, =(HeapMem + Heap)
        LDR     R3, =StackMem
        BX      LR
    ENDIF

;******************************************************************************
;
; Make sure the end of this section is aligned.
;
;******************************************************************************
        ALIGN

;******************************************************************************
;
; Tell the assembler that we're done.
;
;******************************************************************************
        END
