//==============================================================================
// THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES INC. ``AS IS'' AND ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT, ARE
// DISCLAIMED. IN NO EVENT SHALL ANALOG DEVICES INC. BE LIABLE FOR ANY DIRECT,
// INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
//
// YOU ASSUME ANY AND ALL RISK FROM THE USE OF THIS CODE OR SUPPORT FILE.
//
// IT IS THE RESPONSIBILITY OF THE PERSON INTEGRATING THIS CODE INTO AN
// APPLICATION TO ENSURE THAT THE RESULTING APPLICATION PERFORMS AS REQUIRED
// AND IS SAFE.
//
//    Module       : startupADuCM342.c
//    Description  : Cortex-M3 startup file - ADuCM342 Version
//    Date         : Jan 2023
//    Version      : v1.00
//    Changelog    : v1.00 Initial
//
#include <ADuCM342.h>
//==============================================================================
//
// Enable the IAR extensions for this source file.
//
//==============================================================================
#pragma language=extended

//==============================================================================
//
// Forward declaration of the default fault handlers.
//
//==============================================================================
static void ResetHandler(void);
static void NMISR(void);
static void FaultISR(void);
static void IntDefaultHandler(void);
static void SysTickIntrHandler (void);

//==============================================================================
//
// The entry point for the application startup code.
//
//==============================================================================
extern void __iar_program_start(void);

//==============================================================================
//
// Reserve space for the system stack.
//
//==============================================================================
static unsigned long pulStack[384] @ ".noinit";

//==============================================================================
// Place Development Code at 0x7FC & for User Boot Loader Entry
//==============================================================================
/*
 * __root static const unsigned int PageZeroChecksum @ ".Page_Zero_CRC" = 0x16400000;

__root static const unsigned int Boot_Loader_CRC @ ".Boot_Loader_CRC" = 0xFFFFFFFF;

__root static const unsigned int BootLoaderBlock @ ".Boot_Loader_Block_Address" = 0xFFFFFFFF;

#define User_Boot_Loader 0xFFFFFFFF
__root const unsigned int __BootLoaderEntry @ ".Boot_Loader_Entry_Address" = {User_Boot_Loader};
*/

//==============================================================================
//
// A union that describes the entries of the vector table.  The union is needed
// since the first entry is the stack pointer and the remainder are function
// pointers.
//
//==============================================================================
typedef union
{
    void (*pfnHandler)(void);
    unsigned long ulPtr;
}
uVectorEntry;

//==============================================================================
//
// The vector table.  Note that the proper constructs must be placed on this to
// ensure that it ends up at physical address 0x0000.0000.
//
//==============================================================================
extern void WakeUpTimer2Handler (void);     // external defined handler entry
                                            // for Wake-Up Timer (Timer 2) in main.c

__root const uVectorEntry __vector_table[] @ ".intvec" =
{
    { .ulPtr = (unsigned long)pulStack + sizeof(pulStack) },
                                            // The initial stack pointer
    ResetHandler,                           // The reset handler
    NMISR,                                  // The NMI handler
    FaultISR,                               // The hard fault handler
    IntDefaultHandler,                      // The MPU fault handler
    IntDefaultHandler,                      // The bus fault handler
    IntDefaultHandler,                      // The usage fault handler
    0,                                      // Reserved
    0,                                      // Reserved
    0,                                      // Reserved
    0,                                      // Reserved
    IntDefaultHandler,                      // SVCall handler
    IntDefaultHandler,                      // Debug monitor handler
    0,                                      // Reserved
    IntDefaultHandler,                      // The PendSV handler
    SysTickIntrHandler,                     // The SysTick handler
    WakeUpTimer2Handler,                    // Wake Up Timer		[ 0]
    IntDefaultHandler,                      // External Interrupt 0	[ 1]
    IntDefaultHandler,                      // External Interrupt 1	[ 2]
    IntDefaultHandler,                      // Watch Dog Timer		[ 3]
    IntDefaultHandler,                      // General Purpose Timer 	[ 4]
    IntDefaultHandler,                      // ADC			[ 5]
    IntDefaultHandler,                      // FLASH Controller		[ 6]
    IntDefaultHandler,                      // SPI			[ 7]
    IntDefaultHandler,                      // LIN 0			[ 8]
    IntDefaultHandler,                      // LIN 1			[ 9]
    IntDefaultHandler,                      // LIN 2			[10]
    IntDefaultHandler,                      // 2WI			[11]
    IntDefaultHandler,                      // CALOSC			[12]
    IntDefaultHandler,                      // SRAM ECC			[13]
    IntDefaultHandler,                      // External Interrupt 2	[14]
    IntDefaultHandler,                      // RX Pad			[15]
    IntDefaultHandler,                      // External Inetrrupt 3	[16]
    IntDefaultHandler                       // Reserved
};


//==============================================================================
//
// This is the code that gets called when the processor receives a RESET.  This
// simply calls the main routine. If it returns by error a infinite
//
//==============================================================================
static void ResetHandler(void)
{
    __iar_program_start();
    //
    // Enter an infinite loop.
    //
    while(1)
    {
    }
}

//==============================================================================
//
// This is the code that gets called when the processor receives a NMI.  This
// simply enters an infinite loop, preserving the system state for examination
// by a debugger.
//
//==============================================================================
static void NMISR(void)
{
    //
    // Enter an infinite loop.
    //
    while(1)
    {
    }
}

//==============================================================================
//
// This is the code that gets called when the processor receives a fault
// interrupt.  This simply enters an infinite loop, preserving the system state
// for examination by a debugger.
//
//==============================================================================
static void FaultISR(void)
{
    //
    // Enter an infinite loop.
    //
    while(1)
    {
    }
}

//==============================================================================
//
// This is the code that gets called when the processor receives System Tick
// Interrupt.  This simply enters an infinite loop, preserving the system state
// for examination by a debugger- as long it is not used for the application.
//
//==============================================================================
static void SysTickIntrHandler (void)
{
    //
    // Enter an infinite loop.
    //
    while(1)
    {
    }
}


//==============================================================================
//
// This is the code that gets called when the processor receives an unexpected
// interrupt.  This simply enters an infinite loop, preserving the system state
// for examination by a debugger.
//
//==============================================================================
static void
IntDefaultHandler(void)
{
    //
    // Go into an infinite loop.
    //
    while(1)
    {
    }
}
