/*! Copyright (c) 2019 Analog Devices, Inc.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-
INFRINGEMENT, TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF
CLAIMS OF INTELLECTUAL PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.
*****************************************************************************/

//=============================================================
//    Module       : gpt.c
//    Description  : Demonstrates how to use the General Purpose timer.
//									 Timer activates Red and Green LEDs then green then
//					 				 deactivates both at intervals set by T0FC registers.
//    Date         : Jan. 2023
//    Version      : v1.00
//    Changelog    : v1.00 Initial
//	  By		   		 : ADI Apps
//=============================================================

// Includes
#include "ADuCM342.h"             // Component selection
#include <absacc.h>

// Prototypes
void GPIO_Init(void);
void GP_Timer_Init(void);

const unsigned int iPage0CS[2] __at(0x07f8) = {0xffffffff,0x16400000};	// for startup from Kernel to user code
//=====================================================================
// 						main
//=====================================================================
int main (void)
{
 T3CON = 0x00;								// Turn off watchdog
 ISER0 = 0x10;								// Enable GPTimer Interrupt in NVIC
 GPIO_Init();									// Init the GPIOs
 GP_Timer_Init();							// Init the GP Timer

 while(1)
 {
  __WFI();										// wait for interrupt to occur
 }
}

//=====================================================================
// 						GPTimer Interrupt Handler
//=====================================================================
void GP_Tmr_Int_Handler(void)
{
 unsigned short int lcl_T0ISTA;

 lcl_T0ISTA = T0ISTA;
 lcl_T0ISTA &=0xF;						// Grab lower nibble

 switch(lcl_T0ISTA)					  // Only register TOFC is used in this example
 {
	case 0x1:						    		// TOFA Timeout
		T0CLRI = 0x01;						// Clear TOFA interrupt
		break;
	 case 0x2:						    	// TOFB Timeout
		T0CLRI = 0x02;						// Clear TOFB interrupt
		break;
	 case 0x4:						    	// TOFC Timeout
		GP0TGL = 0x0C;
		T0CLRI = 0x04;						// Clear TOFC interrupt
		break;
 }
 __DSB();
}

//=====================================================================
// 						GPTimer Config
//=====================================================================
void GP_Timer_Init(void)
{
 T0EN = 0x0000;
 T0CON = (0 << 5)  							// Write always zero
       | (0 << 4)  							// Periodic
       | (0 << 3)  							// Unfreeze
       | (0 << 2)  							// Count up
       | (3 << 0); 							// 32768 Prescaler

 T0TOFC0 = 0x3E8;
 T0TOFC1 = 0x0000;

 T0IEN =  (0 << 4)  						// Write always zero
				| (0 << 3)  						// Roll Enable
        | (1 << 2)  						// T0FC Int En
        | (0 << 1)  						// T0FB Int En
        | (0 << 0);  						// T0FA Int En

 T0EN = 0x01;
}

//=====================================================================
// 						GPIO Config
//=====================================================================
void GPIO_Init(void)
{
 GP0CON = 0x00;	   							// Enable as GPIOs
 GP0PUL = 0x3F;									// Activate pull ups
 GP0OEN = 0x0C;									// Enable GPIOs as o/p's
}

//=====================================================================
// 						LINint0 Normal LIN Event handler
//=====================================================================
void LIN0_Int_Handler (void)
{
}

//=====================================================================
// 						LINint1 Error Event handler
//=====================================================================
void LIN1_Int_Handler (void)
{
}

//=====================================================================
// 						LINint2 Sleep / Wake Event handler
//=====================================================================
void LIN2_Int_Handler (void)
{
}

//============================================================================
//				SYSTICK Handler
//============================================================================
void SysTick_Int_Handler(void)
{
}

//=====================================================================
// 						WUP Timer Interrupt Handler
//=====================================================================
void WakeUp_Int_Handler(void)
{
}

//=====================================================================
// 						ADC Interrupt Handler
//=====================================================================
void ADC_Int_Handler(void)
{
}

//==========================================================================================
//				Hard Fault Handler, 2bit or >2bit ECC error interrupt
//==========================================================================================
void Hard_Fault_Exception(void)
{
}

