/*! Copyright (c) 2019 Analog Devices, Inc.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-
INFRINGEMENT, TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF
CLAIMS OF INTELLECTUAL PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.
*****************************************************************************/

//=============================================================
//    Module       : main.c
//    Description  : Simple demo on how to use the LIN Interface
//					 		   : if a master sends 0x3D the M342 responds
//					 			 : if the Master sends 0x00 the m33x listens and stores the frame
//    Date         : Jan. 2023
//    Version      : v1.00
//    Changelog    : v1.00 Initial
//	  By		       : ADI Apps
//=============================================================

// Includes
#include "ADuCM342.h"             // Component selection
#include <absacc.h>

// Function Prototypes
void LIN_Init(void);

// Global Variables
unsigned char Diag_Resp[8] = {0x00,0x06,0xF2,0x3A,0x00,0x41,0x4D,0xAA};	    	// 0x3d Response
unsigned char Rx_Frame[8] = {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};	   		// Storage for Master Command Frame

//=====================================================================
// 						main
//=====================================================================
int main (void)
{
 T3CON = 0;  												// Turn off watchdog
 LIN_Init();												// Initialise the LIN interface

 ISER0 = 0x700;											// Enable the LIN interrupts in the NVIC
 while(1)
 {
 }
}

//=====================================================================
// 						LINint0 event Handler, Rx and Tx sources
//=====================================================================
void LIN0_Int_Handler (void)
{
 unsigned int lcl_LINSTA;

 lcl_LINSTA = LINSTA;
 if(lcl_LINSTA & 0x1)	   									  // Header Received.
 {																					// Disable Sleep / Wake timer as LIN is running and interrupt occured.
  LINSTA |= 0x1;
  if(LINID == 0x3D)												  // 0x3D Slave Response Pending to Tx
  {
   LINCNT = 0x8;
   LIND1 = Diag_Resp[0];
   LIND2 = Diag_Resp[1];
   LIND3 = Diag_Resp[2];
   LIND4 = Diag_Resp[3];
   LIND5 = Diag_Resp[4];
   LIND6 = Diag_Resp[5];
   LIND7 = Diag_Resp[6];
   LIND8 = Diag_Resp[7];
   LINCON |= 0x03;													// Transmit
  }
 }
 if(lcl_LINSTA & 0x2)  											// Frame Received
 {
  LINSTA |= 0x2;
  if(LINID == 0x00)													// Listen to Command and store data bytes.
  {
   LINCNT = 0x8;
   Rx_Frame[0] = LIND1;
   Rx_Frame[1] = LIND2;
   Rx_Frame[2] = LIND3;
   Rx_Frame[3] = LIND4;
   Rx_Frame[4] = LIND5;
   Rx_Frame[5] = LIND6;
   Rx_Frame[6] = LIND7;
   Rx_Frame[7] = LIND8;
  }  																				// Check Diagnostic or command frame
 }
 if(lcl_LINSTA & 0x4)  											// Tx Complete
 {
  LINSTA |= 0x4;
 }
}

//=====================================================================
// 						LINint1 Error Handler
//=====================================================================
void LIN1_Int_Handler (void)
{
 LINSTA = 0xFFFF;														// Not interested in any other LINSTA status bits
}

//=====================================================================
// 						LINint2 Handler, Wake Sleep events
//=====================================================================
void LIN2_Int_Handler (void)
{
 LINSTA = 0xFFFF;													 // Not interested in any other LINSTA status bits
}

//=====================================================================
// 						Initialise the LIN for 20kBaud
//=====================================================================
void LIN_Init(void)
{
 unsigned int HVstatus;

 LINCON = 0x5401;													// initialise the LIN logic on bottom die

 do{
  HVDAT = 0x05;														// Enable Top Die LIN Transceiver
  HVCON = 0x08;
  do{
   HVstatus = HVCON;
  }while(HVstatus & 0x01);
 }while(!(HVstatus & 0x04));
}

//============================================================================
//				SYSTICK Handler
//============================================================================
void SysTick_Int_Handler(void)
{
}

//=====================================================================
// 						WUP Timer Interrupt Handler
//=====================================================================
void WakeUp_Int_Handler(void)
{
}

//=====================================================================
// 						GP Timer Interrupt Handler
//=====================================================================
void GP_Tmr_Int_Handler(void)
{
}

//=====================================================================
// 						ADC Interrupt Handler
//=====================================================================
void ADC_Int_Handler(void)
{
}

//==========================================================================================
//				Hard Fault Handler, 2bit or >2bit ECC error interrupt
//==========================================================================================
void Hard_Fault_Exception(void)
{
}

