/*! Copyright (c) 2019 Analog Devices, Inc.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-
INFRINGEMENT, TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF
CLAIMS OF INTELLECTUAL PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.
*****************************************************************************/

//=============================================================
//    Module       : main.c
//    Description  : Demonstrates how to use the internal
//					 				 wakeup timer. Timer wakes & sleeps every 5s
//					 				 Red LED indicates sleep, Green LED indicates awake.
//    Date         : Jan. 2023
//    Version      : v1.00
//    Changelog    : v1.00 Initial
//	  By		       : ADI Apps
//=============================================================

// Includes
#include "ADuCM342.h"             // Component selection
#include <absacc.h>

//Defs
#define TRUE 1
#define FALSE 0

// Prototypes
void GPIO_Init(void);
void WUP_Timer_Init(void);

// Globals
unsigned char Sleep = FALSE;

// Constants
const unsigned int iPage0CS[2] __at(0x07f8) = {0xffffffff,0x16400000};	// for startup from Kernel to user code
//=====================================================================
// 						main
//=====================================================================
int main (void)
{
 T3CON = 0x00;									// Turn off watchdog
 HRFCTRL = 0x00;								// ADC Auto mode
 IRFPD = 0x00;									// Enable Reference buffer
																// as using internal reference
 ISER0 = 0x01;									// Enable WUP Timer Interrupt in NVIC
 GPIO_Init();										// Init the GPIOs
 WUP_Timer_Init();							// Init the WUP Timer

 while(1)
 {
  if(Sleep)
  {
   SCR = 0x4;
   PWRKEY = 0x4859;
   PWRKEY = 0xF27B;							// Prekeys
   PWRMOD = 0x5;
   __DSB();
   __WFI();   									// Goto Sleep
  }
 }
}

//=====================================================================
// 						WUP Timer Interrupt Handler
//=====================================================================
void WakeUp_Int_Handler(void)
{
 unsigned short int lcl_T2ISTA;

 lcl_T2ISTA = T2ISTA;
 lcl_T2ISTA &=0x7;							// Grab lower nibble

 switch(lcl_T2ISTA)
 {
	 case 0x2:						    		// TOFB Timeout
		Sleep = TRUE;
		GP0SET = 0x04;							// Red LED indicates Sleep
		GP0CLR = 0x08;							// Turn off Green LED
		T2CLRI = 0x02;							// Clear TOFB interrupt
		break;
	 case 0x4:						    		// TOFC Timeout
		Sleep = FALSE;
		GP0SET = 0x08;							// Green LED Awake
		GP0CLR = 0x04;							// Turn off Red LED
		T2CLRI = 0x04;							// Clear TOFC interrupt
		break;
 }
}

//=====================================================================
// 						GPTimer Config
//=====================================================================
void WUP_Timer_Init(void)
{
 T2EN = 0x0000;
 T2CON =  (0 << 12)  							// Write always zero
        | (0 << 8)  							// Event Sel
        | (0 << 7)  							// Event Enable
				| (1 << 5)  							// Clock Select
        | (0 << 4)  							// Periodic
        | (0 << 3)  							// Unfreeze
        | (0 << 2)  							// Count up
        | (0 << 0); 							// Divide by 1 prescaler

 T2WUFB0 = 0x8000;								// 5s
 T2WUFB1 = 0x0002;

 T2WUFC0 = 0x0000;								// 5s
 T2WUFC1 = 0x0005;

 T2IEN =  (0 << 4)  							// Write always zero
			  | (0 << 3)  									// Roll Enable
        | (1 << 2)  							// T0FC Int En
        | (1 << 1)  							// T0FB Int Dis
        | (0 << 0);  							// T0FA Int Dis

 T2EN = 0x01;
}

//=====================================================================
// 						GPIO Config
//=====================================================================
void GPIO_Init(void)
{
 GP0CON = 0x00;	   								// Enable as GPIOs
 GP0PUL = 0x3F;										// Activate pull ups
 GP0OEN = 0x3F;										// Enable GPIOs as o/p's
 GP0OUT = 0x08;										// Turn on the Green LED first
}

//=====================================================================
// 						LINint0 Normal LIN Event handler
//=====================================================================
void LIN0_Int_Handler (void)
{
}

//=====================================================================
// 						LINint1 Error Event handler
//=====================================================================
void LIN1_Int_Handler (void)
{
}

//=====================================================================
// 						LINint2 Sleep / Wake Event handler
//=====================================================================
void LIN2_Int_Handler (void)
{
}

//============================================================================
//				SYSTICK Handler
//============================================================================
void SysTick_Int_Handler(void)
{
}

//=====================================================================
// 						GP Timer Interrupt Handler
//=====================================================================
void GP_Tmr_Int_Handler(void)
{
}

//=====================================================================
// 						ADC Interrupt Handler
//=====================================================================
void ADC_Int_Handler(void)
{
}

//==========================================================================================
//				Hard Fault Handler, 2bit or >2bit ECC error interrupt
//==========================================================================================
void Hard_Fault_Exception(void)
{
}

