/*! Copyright (c) 2019 Analog Devices, Inc.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES, INC. AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-
INFRINGEMENT, TITLE, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL ANALOG DEVICES, INC. OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, PUNITIVE OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, DAMAGES ARISING OUT OF
CLAIMS OF INTELLECTUAL PROPERTY RIGHTS INFRINGEMENT; PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.
*****************************************************************************/

//=============================================================
//    Module       : main.c
//    Description  : Demonstrates how to use the internal
//					 				 watchdog timer. Timer gives a 2Hz LED flash until timeout.
//								   Then LED flashes faster after wdog reset. Ensure a full POR is performed first.
//    Date         : Jan. 2023
//    Version      : v1.00
//    Changelog    : v1.00 Initial
//	  By		   : ADI Apps
//=============================================================

// Includes
#include "ADuCM342.h"             // Component selection
#include <absacc.h>

// Prototypes
void GPIO_INIT(void);

// Constants
const unsigned int iPage0CS[2] __at(0x07f8) = {0xffffffff,0x16400000};	// for startup from Kernel to user code
//=====================================================================
// 						main
//=====================================================================
int main (void)
{
 unsigned int lcl_RSTSTA;

 T3CON = 0x00;									// Turn off watchdog

 GPIO_INIT();										// Init the GPIOs

 SysTick_Config(0x640000);			// Load tick value 400ms

 lcl_RSTSTA = RSTSTA;						// Read reset status register
 if((lcl_RSTSTA & 0xF)== 0x0D)  // Indicates POR, SW_RST and WD-RST occured. At first power up only a POR and SW-RST will show.
 {
   SysTick_Config(0x160000);	  // Change to a load tick value 200ms to signify wdog reset occured
 }

 // Configure Watchdog - this will only occur first time through as wdog can only be setup once every POR
 T3LD = 0x2800;
 T3CON = 0x64; 									// Enable with prescale of 16 periodic mode

 while(1)
 {										 					// LEDS should now flash until a reset occurs
 }
}

//=====================================================================
// 						SYSTICK Handler
//=====================================================================
void SysTick_Int_Handler(void)
{
 GP0TGL = 0x0C;
}

//=====================================================================
// 						GPIO Config
//=====================================================================
void GPIO_INIT(void)
{
 GP0CON = 0x00;	   							// Enable as GPIOs
 GP0PUL = 0x33;									// Activate pull ups for i/ps
 GP0OEN = 0x0C;									// Enable GPIO 2,3 as o/p's
}

//=====================================================================
// 						LINint0 Normal LIN Event handler
//=====================================================================
void LIN0_Int_Handler (void)
{
}

//=====================================================================
// 						LINint1 Error Event handler
//=====================================================================
void LIN1_Int_Handler (void)
{
}

//=====================================================================
// 						LINint2 Sleep / Wake Event handler
//=====================================================================
void LIN2_Int_Handler (void)
{
}

//=====================================================================
// 						WUP Timer Interrupt Handler
//=====================================================================
void WakeUp_Int_Handler(void)
{
}

//=====================================================================
// 						GP Timer Interrupt Handler
//=====================================================================
void GP_Tmr_Int_Handler(void)
{
}

//=====================================================================
// 						ADC Interrupt Handler
//=====================================================================
void ADC_Int_Handler(void)
{
}

//==========================================================================================
//				Hard Fault Handler, 2bit or >2bit ECC error interrupt
//==========================================================================================
void Hard_Fault_Exception(void)
{
}

